# #!/usr/bin/env python
# # -*- coding: utf-8 -*-
# # @Project      : AI.  @by PyCharm
# # @File         : images
# # @Time         : 2025/12/24 16:20
# # @Author       : betterme
# # @WeChat       : meutils
# # @Software     : PyCharm
# # @Description  :
#
# from meutils.pipe import *
# from meutils.apis.proxy.kdlapi import get_one_proxy
# from meutils.decorators.retry import retrying, IgnoredRetryException
#
# from meutils.schemas.image_types import ImageRequest, ImagesResponse
#
#
# BASE_URL = "https://image.baidu.com"
# async def generate(payload, token: Optional[str] = None, response_format: str = "url"):
#     s = time.time()
#     # token = token or await get_next_token_for_polling(feishu_url=FEISHU_URL, from_redis=True)
#     headers = {
#         # 'Cookie': token,
#         # 'User-Agent': ua.random,
#         # 'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
#     }
#
#     request_kwargs = {
#         "proxy": await get_one_proxy(),
#     }
#
#     # logger.debug(request_kwargs)
#
#     async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=120, **request_kwargs) as client:
#         response = await client.post("/aigc/pccreate", data=payload)  # pcEditTaskid
#         response.raise_for_status()
#         data = response.json()
#
#         logger.debug(data)
#
#         image_base64 = None
#         if task_id := data.get("pcEditTaskid"):
#             for i in range(30):
#                 await asyncio.sleep(3)
#                 try:
#                     response = await client.get(f'/aigc/pcquery?taskId={task_id}&', )  # todo: get任务未加代理
#                     # logger.debug(response.json())
#                     if data := response.json().get("picArr", []):
#                         image_base64 = data[0].get("src")
#                         break
#                 except Exception as e:
#                     logger.error(e)
#                     if i > 3:
#                         raise IgnoredRetryException(f"忽略重试: \n{response.text}")
#
#         if not image_base64:
#             raise Exception(f"NO WATERMARK FOUND: {data}")  #############
#
#         if response_format == "url":
#             url = await to_url(image_base64, filename=f"{shortuuid.random()}_hd.png", content_type="image/png")
#
#             return ImagesResponse(data=[{"url": url}], timings={"inference": time.time() - s})
#         else:
#             return ImagesResponse(data=[{"b64_json": image_base64}], timings={"inference": time.time() - s})
#
#
# if __name__ == '__main__':
#     image = "https://s3.ffire.cc/files/jimeng.jpg"
#     payload = {
#         "type": "1",  # 去水印
#
#         "picInfo": image,
#         # "picInfo2": mask,
#
#         # # 百度云盘 才会更快
#         # "image_source": "1",
#         # "original_url": baidu_url,
#         # # # 更快但是会有错误
#         # "thumb_url": baidu_url,
#         # 更快但是会有错误
#
#     }
#
#     request = ImageRequest(
#         # model="hunyuan-remove-watermark",
#
#         # model="remove-watermark",
#         model="clarity",
#         # model="expand",
#         # model="rmbg-2.0",
#
#         # image=url,
#         # mask=url,
#
#         # response_format="b64_json"
#     )
#     arun(generate(request))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : images
# @Time         : 2025/12/2 15:34
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import os

from meutils.pipe import *

from openai import AsyncOpenAI
from meutils.llm.openai_utils import to_openai_params
from meutils.schemas.image_types import ImageRequest, ImagesResponse

BASE_URL = 'https://api-inference.modelscope.cn/v1'


async def generate(request: ImageRequest, api_key: Optional[str] = None, base_url: Optional[str] = None, ):
    base_url = base_url or BASE_URL
    api_key = api_key or os.getenv("MODELSCOPE_API_KEY")

    if request.image:
        if 'qwen-image' in request.model.lower():
            if "2509" in request.model:
                request.model = "juyunapi/Qwen-Image-Edit-2509"
            else:
                request.model = "Qwen/Qwen-Image-Edit-2511"

            request.image_url = request.image_urls


    headers = {
        "X-ModelScope-Task-Type": "image_generation",
    }
    data = to_openai_params(request)
    logger.debug(bjson(data))

    client = AsyncOpenAI(base_url=base_url, api_key=api_key, default_headers=headers)

    task_id = None # or "caffccb8-7999-41e7-8222-5dfff9bdaccb"
    for i in range(2):
        try:
            response = await client.images.generate(**data, extra_headers=headers)

            logger.debug(bjson(response))

            if images := response.model_dump().get("images"):
                return ImagesResponse(images=images)
            else:
                task_id = response.model_dump().get("task_id")
                assert task_id, "task_id is None"
        except Exception as e:
            logger.error(e)
            if "submit image generation task error" in str(e):
                headers.update({"X-ModelScope-Async-Mode": "true"})

            if i: raise e

    for i in range(100):
        await asyncio.sleep(3)
        #     "task_id": "caffccb8-7999-41e7-8222-5dfff9bdaccb",

        # result = requests.get(
        #     f"{base_url}/tasks/{task_id}",
        #     headers={"Authorization": f"Bearer {api_key}", "X-ModelScope-Task-Type": "image_generation"},
        # )
        # result.raise_for_status()
        # data = result.json()
        # logger.debug(bjson(data))

        try:
            response = await client.get(
                f"/tasks/{task_id}",
                cast_to=object,
                # cast_to=httpx.Response,

            )
            logger.debug(bjson(response))
            if response["task_status"] == "SUCCEED":  # PENDING PROCESSING
                return ImagesResponse(**response)
            elif response["task_status"] == "FAILED":
                raise Exception("Image Generation Failed.")

        except Exception as e:
            logger.debug(e)


#
# task_id = response.json()["task_id"]
#
# while True:
#     result = requests.get(
#         f"{base_url}v1/tasks/{task_id}",
#         headers={**common_headers, "X-ModelScope-Task-Type": "image_generation"},
#     )
#     result.raise_for_status()
#     data = result.json()
#
#     if data["task_status"] == "SUCCEED":
#         image = Image.open(BytesIO(requests.get(data["output_images"][0]).content))
#         image.save("result_image.jpg")
#         break
#     elif data["task_status"] == "FAILED":
#         print("Image Generation Failed.")
#         break
#
#     time.sleep(5)


if __name__ == '__main__':
    model = "Tongyi-MAI/Z-Image-Turbo"  # todo size
    # model = "black-forest-labs/FLUX.2-dev"
    # model = "Qwen/Qwen-Image"  # 异步
    # model = "Qwen/Qwen-Image-Edit-2511"
    model = "Qwen/Qwen-Image-2512"
    request = ImageRequest(
        model=model,
        prompt="给图中的狗戴上一个生日帽",
        # size="2048x2048",  # 64,2048

        image="https://modelscope.oss-cn-beijing.aliyuncs.com/Dog.png",
    )
    arun(generate(request))





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : openai_asr
# @Time         : 2023/11/23 13:10
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo: 更多模型

from meutils.pipe import *
from openai import OpenAI

# base_url = 'http://0.0.0.0:8000/v1'
# base_url='http://154.3.0.117:39009/tts/v1'
# base_url="https://openai-dev.chatfire.cn/audio/v1"
# base_url="https://openai.chatfire.cn/audio/v1"
# base_url="https://api.chatfire.cn/v2"

client = OpenAI(
    # base_url=base_url,
    # api_key=os.getenv('OPENAI_API_KEY'),

    # api_key=os.getenv('OPENAI_API_KEY_OPENAI') + "-2738",
    # api_key=os.getenv('OPENAI_API_KEY_OPENAI') + "-21172",
    api_key=os.getenv('OPENAI_API_KEY') + "-21172",

)

# text = """
# 陕西省，简称“陕”或“秦”，中华人民共和国省级行政区，省会西安，位于中国内陆腹地，黄河中游，东邻山西、河南，西连宁夏、甘肃，南抵四川、重庆、湖北，北接内蒙古，介于东经105°29′—111°15′，北纬31°42′—39°35′之间，总面积205624.3平方千米。 [1] [5]截至2022年11月，陕西省下辖10个地级市（其中省会西安为副省级市）、31个市辖区、7个县级市、69个县。 [121]截至2022年末，陕西省常住人口3956万人。
# """
# # text = "你好哇"*20
# _ = client.audio.speech.create(input=text, model="tts", voice="晓晓")
# _.stream_to_file("hi.mp3")

with timer():
    voice = "晓晓"
    voice = "alloy"
    speech_file_path = f"{voice}.mp3"
    response = client.audio.speech.create(
        # input="健身需要注意适度和平衡，过度的锻炼可能会导致身体受伤。因此，进行健身活动前，最好先咨询医生或专业的健身教练，制定一个适合自己的健身计划。一般来说，一周内进行150分钟的适度强度的有氧运动，或者75分钟的高强度有氧运动，加上每周两天的肌肉锻炼，就能达到保持健康的目标。",
        input="健身需要注意适度和平衡，过度的锻炼可能会导致身体受伤",

        model="tts-1",
        voice=voice,
        # voice="54a5170264694bfc8e9ad98df7bd89c3"
    )
    # logger.debug(response)
    response.stream_to_file(speech_file_path)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : meta
# @Time         : 2024/11/11 17:03
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from urllib import parse

import requests
import requests
import json

url = "https://metaso.cn/api/session"

question = "东北证券"

payload = json.dumps({
    "question": question,
    "mode": "detail",
    "engineType": "",
    "scholarSearchDomain": "all",
    "searchTopicId": None,
    "searchTopicName": None
})
headers = {
    # 'token': 'wr8+pHu3KYryzz0O2MaBSNUZbVLjLUYC1FR4sKqSW0p19vmcZAoEmHC72zPh/fHt4VdW84WZEx4CbSUTO9sLBF48wX95yi9MJTWNNw3kbBSs6V4qv8FOocFD2ThCrWwXPwROPpwUqLnM2uWfwtUwaw==',
    # 'Cookie': 'JSESSIONID=2A41A2D4F163AA1534CA7B2B152A1C60; tid=b103b947-be89-40b8-b162-80fdcda60807; __eventn_id_UMO2dYNwFz=jdt3ua9m4t; __eventn_id_UMO2dYNwFz_usr=%7B%22email%22%3A%22undefined%40metasota.ai%22%2C%22created_at%22%3A%22Wed%2C%2004%20Sep%202024%2006%3A55%3A57%20GMT%22%7D; aliyungf_tc=8cfbed3e5fd53c2a81605c7dcb63d45d3114b94750922ef63e04cb5a6ceccba1; s=bdpc; usermaven_id_UMO2dYNwFz=4d3f1r1j6i; hideLeftMenu=1; newSearch=false',
    # 'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
    'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)

logger.debug(response.text)

session_id = response.json()['data']['id']
#
# # dict(parse.parse_qsl(url)[1:])
# url = "https://metaso.cn/api/searchV2"
#
# params = {
#     'question': question,
#     "sessionId": session_id,
#     'lang': 'zh',
#     'mode': 'detail',
#     # 'url': f'https://metaso.cn/search/{sessionId}?q={q}',
#     'enableMix': 'true',
#     'scholarSearchDomain': 'all',
#     'expectedCurrentSessionSearchCount': '1',
#     'newEngine': 'true',
#     'enableImage': 'true',
#     'token': 'wr8+pHu3KYryzz0O2MaBSNUZbVLjLUYC1FR4sKqSW0p19vmcZAoEmHC72zPh/fHt4VdW84WZEx4CbSUTO9sLBF48wX95yi9MJTWNNw3kbBSs6V4qv8FOocFD2ThCrWwXPwROPpwUqLnM2uWfwtUwaw=='
# }
# payload = {}
# headers = {
#     # 'Cookie': 'JSESSIONID=4ED87E5C0CD2AF6875227D279DFFBB16; tid=b103b947-be89-40b8-b162-80fdcda60807; __eventn_id_UMO2dYNwFz=jdt3ua9m4t; __eventn_id_UMO2dYNwFz_usr=%7B%22email%22%3A%22undefined%40metasota.ai%22%2C%22created_at%22%3A%22Wed%2C%2004%20Sep%202024%2006%3A55%3A57%20GMT%22%7D; aliyungf_tc=8cfbed3e5fd53c2a81605c7dcb63d45d3114b94750922ef63e04cb5a6ceccba1; s=bdpc; usermaven_id_UMO2dYNwFz=4d3f1r1j6i; hideLeftMenu=1; newSearch=false',
#     # 'User-Agent': 'Apifox/1.0.0 (https://apifox.com)'
# }
# #
# response = requests.request("GET", url, headers=headers, data=payload, params=params)
# #
# print(response.text)
# async with httpx.AsyncClient(base_url=YUANBAO_BASE_URL, headers=headers, timeout=300) as client:
#     # chatid = (await client.post(API_GENERATE_ID)).text
#     chatid = uuid.uuid4()
#
#     async with client.stream(method="POST", url=f"{API_CHAT}/{chatid}", json=payload) as response:
#         logger.debug(response.status_code)
#         response.raise_for_status()
#
#         async for chunk in response.aiter_lines():


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : images
# @Time         : 2024/10/28 15:15
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from meutils.schemas.tripo3d_types import BASE_URL, FEISHU_URL

from meutils.schemas.tripo3d_types import ImageRequest, TaskResponse
from meutils.config_utils.lark_utils import get_next_token_for_polling

from meutils.notice.feishu import send_message as _send_message, IMAGES

send_message = partial(
    _send_message,
    title=__name__,
    url=IMAGES
)


# @retrying(predicate=lambda r: r.base_resp.status_code in {1000061, })  # 限流
async def create_task(request: ImageRequest, token: Optional[str] = None, vip: Optional[bool] = True):
    token = token or await get_next_token_for_polling(FEISHU_URL)

    payload = request.model_dump()

    headers = {
        "Authorization": f"Bearer {token}"
    }
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post("/v2/web/task", json=payload)
        response.raise_for_status()
        data = response.json()

        return TaskResponse(**data, system_fingerprint=token)


async def get_task(task_id: str, token: str):
    # task_id = task_id.rsplit('-', 1)[-1]

    headers = {
        "Authorization": f"Bearer {token}"
    }
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.get(f"/v2/web/task/{task_id}")
        response.raise_for_status()
        data = response.json()
        return data

        # {
        #     "code": 0,
        #     "data": {
        #         "task_id": "41df5dd5-19c2-4df4-9f4f-71d0cf63d83e",
        #         "type": "text_to_model",
        #         "status": "running",
        #         "progress": 99,
        #         "input": {
        #             "prompt": "一只活泼的柴犬，戴着红白相间的头巾，叼着一根魔法棒，眼睛闪烁着星星，正在表演马戏团特技",
        #             "model_version": "v2.0-20240919"
        #         },
        #         "name": "一只活泼的柴犬，戴着红白相间的头巾，叼着一根魔法棒，眼睛闪烁着星星，正在表演马戏团特技",
        #         "create_time": 1730099666,
        #         "prompt": "一只活泼的柴犬，戴着红白相间的头巾，叼着一根魔法棒，眼睛闪烁着星星，正在表演马戏团特技",
        #         "queuing_num": -1,
        #         "running_left_time": 1,
        #         "is_owner": true,
        #         "pbr_model": "https://tripo-data.cdn.bcebos.com/tcli_ba9f78ef47fd4c559801b2e57f54d26d/20241028/41df5dd5-19c2-4df4-9f4f-71d0cf63d83e/tripo_pbr_model_41df5dd5-19c2-4df4-9f4f-71d0cf63d83e.glb?auth_key=1730099847-XQdJD3SG-0-95f98da862962563cb68b1c0beed395b",
        #         "rendered_sequence": "https://tripo   -data.cdn.bcebos.com/tcli_ba9f78ef47fd4c559801b2e57f54d26d/20241028/41df5dd5-19c2-4df4-9f4f-71d0cf63d83e/composite_spin_frame_41df5dd5-19c2-4df4-9f4f-71d0cf63d83e.webp?auth_key=1730099847-1vfLjTnM-0-d8178772aad0d0f682ed9bddfa9b7804"
        #     }
        # }


async def check_token(token: str, threshold: int = 0):
    headers = {
        "Authorization": f"Bearer {token}"
    }
    try:
        async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
            response = await client.get("/v2/web/billing/wallet/all")
            response.raise_for_status()
            data = response.json()
            logger.debug(bjson(data))
            return data['data']['total_balance'] > threshold


    except Exception as e:
        logger.error(e)
        return False


if __name__ == '__main__':
    token = "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiIsImtpZCI6ImQwbDJldGdSeEd5Q19FVFZyOGgzRG9LMWxqa3ZCN0puQ1pPbTVwUFRyelkifQ.eyJzdWIiOiI2NzFmMzk0ZjQ3ZmUyZDg0ZjNjMGRhMzEiLCJhdWQiOiI2NWIyNTAzMjAxZjQwODZjMDQzZDcxMWYiLCJzY29wZSI6ImFkZHJlc3MgZW1haWwgcHJvZmlsZSBwaG9uZSBvcGVuaWQiLCJpYXQiOjE3MzAwOTk1NDAsImV4cCI6MTczMTMwOTE0MCwianRpIjoiQ2ZoZ2I0cHROcmVCM2RXSzJwZjhwX3N2eUZjSkZrcmpHY0haV0FoSVotLSIsImlzcyI6Imh0dHBzOi8vdHJpcG8td2ViLnVzLmF1dGhpbmcuY28vb2lkYyJ9.P2q1Y82VGem-0PSIP7A9etnclK73IfWbGcBrBa-NrxBH-CJNRHQy-eehCcLEaIPX879dqZeeTzCWwKc07rw3M4jfLj4Gqm7hrdFHZxGi4gT0vwgkKpxEU_iwn773Yx6L3N5aMpXsMqDoj_i2cuIU2mt6PET0rhErE1i1hqM1rh_BSZBuRpYZTKMOwMbcay7xn2SAcsGX0nHKXcv0nmRWXoMpn_-RbYOoddVO2cAe5SCPe168-OJ7RQN-I2lV-VE7ZQp_wCy2pxOVdY8iekKCp42wnutYHHE1kSgEN_ac6v0CINqx9CFw0TT6qBVYlsPUliq4tCX2YRwiaYZtqI8RRw"

    # arun(check_token(token))
    # arun(get_task("e25d3012-ec08-482f-90a9-fd9b356df6ed", token))

    request = ImageRequest(
        prompt="一只活泼的柴犬，戴着红白相间的头巾，叼着一根魔法棒，眼睛闪烁着星星，正在表演马戏团特技",
    )
    arun(create_task(request))  # 60*100



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : schedule
# @Time         : 2021/4/27 10:00 下午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : https://www.cnblogs.com/longsongpong/p/10998619.html


import time
import schedule
from loguru import logger
from meutils.decorators.decorator import decorator


@decorator
def scheduler(func, scheduler_=schedule.every(2).seconds, stop_func=lambda: True, *args, **kwargs):
    """设置调度的参数，这里是每2秒执行一次

        t = time.time() + 10
        def f():
            time.sleep(1)
            return time.time() > t


        @scheduler(stop_func=f)
        def job(arg):
            print(f"{arg}: a simple scheduler in python.")

    :param func:
    :param scheduler_:
    :param stop_func:
    :param args:
    :param kwargs:
    :return:
    """
    # 先初始化一次
    logger.info(f"{func.__name__} 调度初始化: {func(*args, **kwargs)}")

    # 正式调度
    scheduler_.do(func, *args, **kwargs)

    while True:
        schedule.run_pending()

        if stop_func():
            logger.info(f"{func.__name__} 调度终止")
            break


if __name__ == '__main__':
    t = time.time() + 10


    def f():
        return time.time() > t  # 监控知道为True


    @scheduler(stop_func=f)
    def job(arg):
        print(f"{arg}: a simple scheduler in python.")


    job(1)

    # def job2(arg):
    #     print(f"{arg}: a simple scheduler in python.")
    #     return 'xxxxxx'
    # a = schedule.every(2).seconds.do(job2, arg='TEST')
    # while True:
    #     schedule.run_pending()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : common
# @Time         : 2023/11/8 13:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : rq worker --with-scheduler

from meutils.pipe import *
from meutils.decorators.retry import retrying


def do_task(**kwargs):
    time.sleep(3)
    return kwargs


@retrying
def request_task(**kwargs):
    method = kwargs.pop('method', '')
    url = kwargs.pop('url', '')

    response = requests.request(method, url, **kwargs)  # request(method, url, **kwargs)

    return response.json()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : sql
# @Time         : 2025/9/24 21:06
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
# !/usr/bin/env python3
# -*- coding: utf-8 -*-

from datetime import datetime, timedelta
import calendar
import sys


def generate_partition_script_by_dates(start_date_str, end_date_str):
    """
    根据开始和结束日期生成MySQL RANGE分区脚本

    Args:
        start_date_str: 开始日期，格式 'YYYY-MM-DD'
        end_date_str: 结束日期，格式 'YYYY-MM-DD'

    Returns:
        str: 完整的分区SQL脚本
    """
    try:
        start_date = datetime.strptime(start_date_str, '%Y-%m-%d')
        end_date = datetime.strptime(end_date_str, '%Y-%m-%d')
    except ValueError as e:
        raise ValueError(f"日期格式错误，请使用 YYYY-MM-DD 格式: {e}")

    if start_date > end_date:
        raise ValueError("开始日期不能晚于结束日期")

    # 生成所有日期
    current_date = start_date
    dates = []
    while current_date <= end_date:
        dates.append(current_date)
        current_date += timedelta(days=1)

    # 生成分区定义
    partition_lines = []
    for date in dates:
        partition_name = f"p{date.strftime('%Y%m%d')}"
        next_day = date + timedelta(days=1)
        next_day_str = next_day.strftime('%Y-%m-%d')
        partition_line = f"  PARTITION {partition_name} VALUES LESS THAN (UNIX_TIMESTAMP('{next_day_str} 00:00:00'))"
        partition_lines.append(partition_line)

    # 添加兜底分区
    partition_lines.append("  PARTITION pmax VALUES LESS THAN MAXVALUE")

    # 组装完整SQL
    sql_script = "ALTER TABLE logs\nPARTITION BY RANGE (created_at) (\n" + ",\n".join(partition_lines) + "\n);"

    return sql_script


def generate_partition_script_by_month(year, month):
    """
    根据年份和月份生成该月的分区脚本

    Args:
        year: 年份 (int)
        month: 月份 (int, 1-12)

    Returns:
        str: 完整的分区SQL脚本
    """
    if not (1 <= month <= 12):
        raise ValueError("月份必须在 1-12 之间")

    # 获取该月的天数
    days_in_month = calendar.monthrange(year, month)[1]

    start_date = f"{year:04d}-{month:02d}-01"
    end_date = f"{year:04d}-{month:02d}-{days_in_month:02d}"

    return generate_partition_script_by_dates(start_date, end_date)


def main():
    """主函数，提供交互式界面"""
    print("MySQL 分区脚本生成器")
    print("=" * 30)
    print("1. 按日期范围生成 (YYYY-MM-DD 到 YYYY-MM-DD)")
    print("2. 按月份生成 (年份 月份)")

    try:
        choice = input("\n请选择生成方式 (1 或 2): ").strip()

        if choice == "1":
            start_date = input("请输入开始日期 (YYYY-MM-DD): ").strip()
            end_date = input("请输入结束日期 (YYYY-MM-DD): ").strip()
            script = generate_partition_script_by_dates(start_date, end_date)

        elif choice == "2":
            year = int(input("请输入年份 (如 2025): "))
            month = int(input("请输入月份 (1-12): "))
            script = generate_partition_script_by_month(year, month)

        else:
            print("无效选择！")
            return

        # 输出结果
        print("\n" + "=" * 50)
        print("生成的分区脚本:")
        print("=" * 50)
        print(script)

        # 询问是否保存到文件
        save_choice = input("\n是否保存到文件? (y/n): ").strip().lower()
        if save_choice == 'y':
            filename = input("请输入文件名 (默认: partitions.sql): ").strip()
            if not filename:
                filename = "partitions.sql"

            with open(filename, 'w', encoding='utf-8') as f:
                f.write(script)
            print(f"脚本已保存到: {filename}")

    except KeyboardInterrupt:
        print("\n\n操作已取消")
    except Exception as e:
        print(f"\n错误: {e}")


if __name__ == "__main__":
    # 按日期范围生成
    script = generate_partition_script_by_dates('2025-12-12', '2027-01-01')
    print(script)

    # 按月份生成
    # script = generate_partition_script_by_month(2025, 10)  # 2025年10月

    """
    -- 1. 创建新表（带合理分区）
    CREATE TABLE logs_new LIKE logs;
    -- 手动添加按月分区定义（如上）
    
    -- 2. 逐步迁移数据（按天/按小时）
    INSERT INTO logs_new 
    SELECT * FROM logs 
    WHERE created_at > UNIX_TIMESTAMP('2025-09-24 00:00:00');
    
    -- 3. 应用双写 or 停写切换
    RENAME TABLE logs TO logs_old, logs_new TO logs;

    SELECT count(1) FROM `logs` WHERE created_at > UNIX_TIMESTAMP('2025-09-24 00:00:00')
    """


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : app
# @Time         : 2023/8/4 11:15
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://blog.csdn.net/weixin_43354181/article/details/126753700
# https://blog.csdn.net/weixin_43047908/article/details/128383893


from meutils.pipe import *
from celery import Celery, shared_task, states

############################################################
CELERY_BROKER = os.getenv('REDIS_URL', 'redis://127.0.0.1:6379')
CELERY_BACKEND = os.getenv('CELERY_BACKEND', f"{CELERY_BROKER}/1")
CELERY_MAX_RETRIES = int(os.getenv('CELERY_MAX_RETRIES', 6))
############################################################

app = Celery(
    'MeutilsCelery',
    broker=CELERY_BROKER,
    backend=CELERY_BACKEND,
)

app.conf.update(
    result_expires=30 * 24 * 60 * 60,
    enable_utc=False,
    timezone='Asia/Shanghai',
    task_track_started=True,
)

# shared_task = app.task
# app.config_from_envvar
# app.config_from_cmdline

@shared_task()
def do_task(**kwargs):
    return kwargs


@shared_task(
    autoretry_for=(Exception,),

    retry_backoff=True,
    # retry_backoff_max=60, # 2 ** max_retries
    retry_jitter=False,

    retry_kwargs={'max_retries': CELERY_MAX_RETRIES}
)
def proxy_task(**kwargs):
    method = kwargs.pop('method', '')
    url = kwargs.pop('url', '')

    logger.debug(kwargs)

    response = requests.request(method, url, **kwargs).json()

    return response



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : x
# @Time         : 2024/9/25 10:42
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://ai.gitee.com/hf-models/giacomoarienti/nsfw-classifier/api

from meutils.pipe import *
from meutils.hash_utils import md5

# md5("8daf5c4765c493e2")
from openai import OpenAI

client = OpenAI(
	base_url="https://ai.gitee.com/v1",
	api_key="WPCSA3ZYD8KBQQ2ZKTAPVUA059J2Q47TLWGB2ZMQ",
	default_headers={"X-Package":"1910"},
)

response = client.moderations.create(
	model="nsfw-classifier",
	input=[
		{
			"type": "image_url",
			"image_url": {
				"url": "https://oss.ffire.cc/files/kling_watermark.png"
			}
		}
	],
)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : ocr_api
# @Time         : 2023/8/23 13:16
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://ai.baidu.com/ai-doc/OCR/9k3h7xuv6

from meutils.pipe import *
from meutils.cache_utils import ttl_cache
from meutils.decorators.retry import retrying
from aip import AipOcr


class OCR(AipOcr):

    def __init__(self, app_id=None, api_key=None, secret_key=None, predicate=lambda r: r is None or 'error_code' in r):
        """

        :param app_id:
        :param api_key:
        :param secret_key:
        :param predicate: 增加重试条件，有错误代码时重试
        """

        _ = os.getenv('BAIDU_AI', '').split(':') or (app_id, api_key, secret_key)
        assert any(_), "请配置正确的key"

        super().__init__(*_)

        self._request = retrying(ttl_cache()(self._request), predicate=predicate)  # todo: 异步

    @classmethod
    @lru_cache
    def basic_accurate(cls, image, options=None, return_json=False):
        """
            with timer('basic_accurate'):
                img = Path("/Users/betterme/PycharmProjects/AI/aizoo/aizoo/api/港澳台通行证.webp").read_bytes()
                rprint(OCR.basic_accurate(img))
        """
        options = options or {}
        # options["language_type"] = "CHN_ENG"
        # options["detect_direction"] = "true"
        # options["detect_language"] = "true"
        # options["probability"] = "true"

        _ = cls().basicAccurate(image, options)  # todo: 增加错误处理
        # super(OCR, cls()).basicAccurate(url, options)
        if return_json:
            _ = json.dumps(_, ensure_ascii=False)
        return _


if __name__ == '__main__':
    pass
    # url = 'https://tva1.sinaimg.cn/large/e6c9d24egy1h36evn3pcoj20af06tq3c.jpg'
    #
    # with timer(1):
    #     rprint(OCR().basicAccurateUrl(url))
    #
    # with timer(2):
    #     rprint(OCR().basicAccurateUrl(url))

    rprint(OCR().basicAccurate(Path('img.png').read_bytes()))

    # with timer('basic_accurate'):
    #     img = Path("/Users/betterme/PycharmProjects/AI/aizoo/aizoo/api/港澳台通行证.webp").read_bytes()
    #     rprint(OCR.basic_accurate(img))


from modelscope import AutoModelForCausalLM, AutoTokenizer, snapshot_download
from modelscope import GenerationConfig


# 注意，celery4版本后，CELERY_BROKER_URL改为BROKER_URL
# https://www.yii666.com/article/344444.html

broker_url = 'amqp://username:passwd@host:port/虚拟主机名'

# 指定结果的接受地址

celery_result_backend = 'redis://username:passwd@host:port/db'

# 指定任务序列化方式 binary json msgpack

celery_task_serializer = 'msgpack'

# 指定结果序列化方式

celery_result_serializer = 'msgpack'

# 任务过期时间,celery任务执行结果的超时时间

celery_task_result_expires = 60 * 20

# 指定任务接受的序列化类型.

celery_accept_content = ["msgpack"]

# 任务发送完成是否需要确认，这一项对性能有一点影响

celery_acks_late = True

# 压缩方案选择，可以是zlib, bzip2，默认是发送没有压缩的数据

celery_message_compression = 'zlib'

# 规定完成任务的时间

celeryd_task_time_limit = 5  # 在5s内完成任务，否则执行该任务的worker将被杀死，任务移交给父进程

# celery worker的并发数，默认是服务器的内核数目,也是命令行-c参数指定的数目

celeryd_concurrency = 4

# celery worker 每次去rabbitmq预取任务的数量

celeryd_prefetch_multiplier = 4

# 每个worker执行了多少任务就会死掉，默认是无限的

celeryd_max_tasks_per_child = 40

# 设置默认的队列名称，如果一个消息不符合其他的队列就会放在默认队列里面，如果什么都不设置的话，数据都会发送到默认的队列中

celery_default_queue = "default"

# 设置详细的队列

celery_queues = {

    "default": {  # 这是上面指定的默认队列

        "exchange": "default",

        "exchange_type": "direct",

        "routing_key": "default"

    },

    "topicqueue": {  # 这是一个topic队列 凡是topictest开头的routing key都会被放到这个队列

        "routing_key": "topic.#",

        "exchange": "topic_exchange",

        "exchange_type": "topic",

    },

    "task_eeg": {  # 设置扇形交换机

        "exchange": "tasks",

        "exchange_type": "fanout",

        "binding_key": "tasks",

    },

}



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2024/10/21 20:17
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://platform.minimaxi.com/document/video_generation?key=66d1439376e52fcee2853049
# https://useapi.net/docs/start-here/setup-minimax
# token 过期时间一个月: 看下free hailuo
# https://jwt.io/

# todo: check token

import oss2

from meutils.pipe import *
from meutils.hash_utils import md5
from meutils.io.files_utils import to_bytes
from meutils.jwt_utils import decode_jwt_token
from meutils.str_utils.json_utils import json_path

from meutils.schemas.image_types import ImageRequest, ImagesResponse

from meutils.schemas.hailuo_types import BASE_URL, FEISHU_URL
# from meutils.schemas.hailuo_types import BASE_URL_ABROAD as BASE_URL, FEISHU_URL_ABROAD as FEISHU_URL
from meutils.schemas.hailuo_types import BASE_URL_ABROAD as BASE_URL
from meutils.schemas.hailuo_types import VideoRequest, VideoResponse
from meutils.llm.check_utils import check_tokens
from meutils.config_utils.lark_utils import get_next_token_for_polling
from meutils.decorators.retry import retrying
from meutils.notice.feishu import send_message as _send_message, VIDEOS

from meutils.apis.hailuoai.yy import get_yy

send_message = partial(
    _send_message,
    title=__name__,
    url=VIDEOS
)

MODEL_MAPPING = {
    # video-01 video-01 video-01-live2d S2V-01

    "t2v-01": "23000",  # 23010
    "t2v-01-director": "23010",

    "i2v-01": "23001",
    "i2v-01-live": "23011",
    "video-01-live2d": "23011",
    "s2v-01": "23021",
}

PARAMS = {
    'device_platform': 'web',
    'app_id': '3001',
    'version_code': '22203',
    'biz_id': '0',
    'os_name': 'Mac',
    'browser_name': 'chrome',
    'device_memory': '8',
    'cpu_core_num': '10',
    'browser_language': 'zh-CN',
    'browser_platform': 'MacIntel',
    'screen_width': '1920',
    'screen_height': '1080',
    'lang':"zh-Intl",

    'uuid': '8c059369-00bf-4777-a426-d9c9b7984ee6',
    'device_id': '339114928865529864',
    'unix': f'{int(time.time())}000'
}
PARAMS = {
    "device_platform": "web",
    "app_id": 3001,
    "version_code": 22203,
    "biz_id": 0,
    "unix": 1768826570000,
    "lang": "zh-Intl",
    "uuid": "6a0f13b1-a471-488a-9328-e53843dc0a90",
    "device_id": 339114928865529864,
    "os_name": "Mac",
    "browser_name": "chrome",
    "device_memory": 8,
    "cpu_core_num": 10,
    "browser_language": "zh-CN",
    "browser_platform": "MacIntel",
    "screen_width": 1352,
    "screen_height": 878
}

# minimax_video-01,minimax_video-01-live2d,,minimax_t2v-01,minimax_i2v-01,minimax_i2v-01-live,minimax_s2v-01


async def upload(file: bytes, token: str):
    data = await get_request_policy(token)

    access_key_id = data["accessKeyId"]
    access_key_secret = data["accessKeySecret"]
    security_token = data["securityToken"]
    bucket_name = data["bucketName"]
    endpoint = data["endpoint"]
    dir = data["dir"]

    # 创建OSS客户端    with timer():
    #         arun(hailuo_upload(file))
    auth = oss2.StsAuth(access_key_id, access_key_secret, security_token)
    bucket = oss2.Bucket(auth, endpoint, bucket_name)

    # file
    size = len(file)

    # 要上传的文件路径和文件名
    mimeType = "png"
    filename = f"{uuid.uuid4()}.{mimeType}"
    object_name = f"{dir}/{filename}"  # png写死
    bucket.put_object(object_name, file)

    params = {}
    payload = {
        "originFileName": "_.png",
        # "originFileName": "503af3b5-9c3b-4bdc-a6d4-256debce3dd5_00001_.png",

        "filename": filename,
        # "fileName": "db884a7c-99a4-40f5-929e-db8769dbf64a.png",

        "dir": dir,
        "endpoint": "oss-cn-wulanchabu.aliyuncs.com",
        "bucketName": "minimax-public-cdn",
        "size": f"{size}",
        "mimeType": mimeType,
        "fileMd5": md5(file),
        "fileScene": 10
    }
    headers = {
        'token': token
    }
    logger.debug(headers)

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=120) as client:
        response = await client.post("/v1/api/files/policy_callback", params=params, json=payload)
        response.raise_for_status()
        data = response.json()
        logger.debug(bjson(data))
        return data

    # {'data': {'fileID': '307139766909288449',
    #           'ossPath': 'https://cdn.hailuoai.com/prod/2024-10-28-10/user/multi_chat_file/c9d8fc64-d9bf-42c0-8779-f39973579fca.png?image_process=resize,fw_320/format,webp'},
    #  'statusInfo': {'code': 0,
    #                 'debugInfo': '',
    #                 'httpCode': 0,
    #                 'message': '成功',
    #                 'requestID': '33a42a75-15e5-4d4e-b425-eeefc4d3f374',
    #                 'serverAlert': 0,
    #                 'serviceTime': 1730083971}}


@alru_cache(ttl=1 * 24 * 60 * 60)
@retrying()
async def get_access_token(token: str):
    logger.debug(f"get_access_token:{token}")

    params = {
        **PARAMS,
        'unix': f'{int(time.time())}000'
    }
    logger.debug(params)
    payload = {}
    headers = {
        'Content-Type': 'application/json',
        'token': token,
        'yy': get_yy(payload, params=params, url="/v1/api/user/renewal")
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post("/v1/api/user/renewal", params=params, content=json.dumps(payload))
        response.raise_for_status()
        logger.debug(response.json())
        return response.json()['data']['token']


@alru_cache(ttl=1 * 60)
async def get_request_policy(token):
    """
    {
        "data": {
            "accessKeyId": "STS.NUVNbdQfqTNixCxUTAhdeJToq",
            "accessKeySecret": "DRBsh8Qm8VnXXxTwFMX5KkXVoqbbsPj4ewEfgTLysGvM",
            "securityToken": "CAISiwN1q6Ft5B2yfSjIr5bjBdjQvLlQ44yCemXJsVQUZOtJpZHEkzz2IHhMf3VpAusWsPw1n2tT6/sdlrBoS4JMREPJN5EhtsQLrl75PdKY4Jzltedb0EIf6JFQUUyV5tTbRsmkZj+0GJ70GUem+wZ3xbzlD2vAO3WuLZyOj7N+c90TRXPWRDFaBdBQVH0AzcgBLinpKOqKOBzniXayaU1zoVhYiHhj0a2l3tbmvHi4tlDhzfIPrIncO4Wta9IWXK1ySNCoxud7BOCjmCdb8EpN77wkzv4GqzLGuNCYCkkU+wiMN+vft9ZjKkg7RNBjSvMa8aWlzKYn57OCyt2v8XsXY7EJCRa4bZu73c7JFNmuMtsEbrvhMxzPqIvXbsKp6lh/MSxDblgRIId8dWURExUpTSrBIaOh6M4Bo5NbzHzuOsgSpnkVpz2AlbLiT9M/1aieRiRTcymwO/ayjeq6CeAF3mM8Mm0qPRouTM2+Zo5YD3N1opjTpiapdUYLox8awbuQLp25tMiF6FiLDvouuRqAAQJZHVcOeb5qnR6mkzw5hwzSOXoMXVFzDE2aB7dvRYFD9HiG6T66hE4Xlfpph9H7xWrpaBf5vqHQXp4gyuqVOgFIjdPECwisXlyAKQWMak7bGToh3cetCux3pjq74sP/KAjzSzDkwciJBbn8vZzNKKR/ozxqve925vtPPPWGPowwIAA=",
            "expiration": "2024-10-22T02:55:14Z",
            "dir": "cdn-yingshi-ai-com/prod/2024-10-22-09/user/multi_chat_file",
            "endpoint": "oss-cn-wulanchabu.aliyuncs.com",
            "bucketName": "minimax-public-cdn",
            "serverTime": "2024-10-22T02:10:07Z"
        }
    }
    """
    token = await get_access_token(token)

    headers = {
        'token': token,
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36',
    }

    logger.debug(headers)

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.get("/v1/api/files/request_policy")
        response.raise_for_status()
        return response.json()['data']
    # return {'accessKeyId': 'STS.NTjAXdazuDwvBugixueiNTwvW',
    #         'accessKeySecret': '4Uj1cuUQt2Xxnr21Yv41CUfGjnH8wBM3SB2Hn9sNrdDS',
    #         'bucketName': 'hailuo-video',
    #         'dir': 'moss/prod/2024-11-08-18/user/multi_chat_file',
    #         'endpoint': 'oss-us-east-1.aliyuncs.com',
    #         'expiration': '2024-11-08T11:38:31Z',
    #         'securityToken': 'CAISjwN1q6Ft5B2yfSjIr5ffCuLQjKVU87WdQFPWjXggaeZiu7LdtTz2IHhMe3lrB+kZsvo0lGFR5vcelrBoS4JMREPJNpMvv8UGq1LxMtKZ45PtseRZ0Fx+t9xLUUyV5tTbRsmkZsW/E67fejKpvyt3xqSAK1fGdle5MJqPpId6Z9AMJGeRZiZHA9EkUGkHr9QBZ0PMKdGnMBPhngi1C1Fz6C59kn9H4L6j2bfMiHzkgUb91/UeqqnoP5GgdLMMBppkVMqv1+EEAsiz2SVLuR9R7/U03u4W+T7GusyaRkdQ7xiBdKj2ioAzcFQhP/JmRfUe86Ghy6JC17aNx9Sn+XFkJvpIVinTfoekzfbfFfmhXtRDLu6jZCSWjInQaseu41J9MSNHLnNDY9tkMWNrTBs3UXTaI66j5VePfAavRq+VN3TYejPRcjQClPr9xDjnK93xuU5wsa8t6v7tUjA8KaFMoG7n3kGenWkdc5K/Z6udEt4wZ+3GM2OsuFNOQI8ZwZ+aRbfi3op7DyGXmSCG59Z1DPwagAF6Ybpx1FU5RRhp1G6yFZrwSz1uWkDL+5K5SYiq9g758m0ElogR5mgmkISgo2qy8/2br2XEA4eyRt5iIHSVX+lLrE2DIv4Cd65nZSQWX8G+av0D5qxCmspJEz3+VL4kdSxT42GuFpu9jhUtWLAX4K/5laoNyKR5LJHtZR3/pteBSCAA',
    #         'serverTime': '2024-11-08T10:38:31Z'}


@retrying(predicate=lambda r: r.base_resp.status_code in {1000061, 1500009})  # 限流
async def create_task(request: ImageRequest, token: Optional[str] = None):
    refresh_token = token

    token = await get_access_token(refresh_token) ##########

    payload = {
        "desc": request.prompt,
        "useOriginPrompt": False,
        "fileList": [],
        "modelID": request.model.removeprefix("hailuo-"),  # hailuo- "image-01"
        "quantity": f"{request.n}",
        "aspectRatio": request.aspect_ratio or "1:1",
    }
    payload = {
        "quantity": f"{request.n}",
        "parameter": {
            "modelID": "nano-banana2",
            "desc": "a cat",
            "fileList": [],
            "useOriginPrompt": True,
            "aspectRatio": "Auto",
            "resolution": "1K"
        }
    }

    if request.prompt.startswith("http"):
        url = request.prompt.split(maxsplit=1)[0]

        data = await upload(await to_bytes(url), token=refresh_token)

        file_data = {
            "id": data['data']['fileID'],
            "name": "_.png",
            "type": "png",
            "url": data['data']['ossPath'],

            # "characterID": "334024935389642756"

        }

        payload["fileList"].append(file_data)
        payload['desc'] = request.prompt.replace(url, " ")

    logger.debug(bjson(payload))

    params = {
        **PARAMS,
        'unix': f'{int(time.time())}000'
    }
    path = "/v2/api/multimodal/generate/image"
    yy = get_yy(payload, params, url=path)
    logger.debug(yy)
    headers = {
        'Content-Type': 'application/json',
        'token': token,
        'yy': yy,
    }
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post(path, params=params, content=json.dumps(payload))
        response.raise_for_status()

        data = response.json()

        logger.debug(bjson(data))

        task_id = (data.get('data') or {}).get('id', '')
        response = VideoResponse(
            task_id=f"hailuoai-{task_id}",
            base_resp=data.get('statusInfo', {}),
            system_fingerprint=refresh_token
        )
        if response.base_resp.status_code != 0:  # 451
            from fastapi import HTTPException, status
            raise HTTPException(status_code=status.HTTP_451_UNAVAILABLE_FOR_LEGAL_REASONS,
                                detail=response.base_resp)

        return response


async def get_task(task_id: str, token: str):
    task_id = task_id.rsplit('-', 1)[-1]

    params = {
        **PARAMS,
        'unix': f'{int(time.time())}000'
    }

    payload = {
        "batchInfoList": [{"batchID": task_id, "batchType": 1}]
    }

    path = "/v4/api/multimodal/video/processing"
    # path = "/api/multimodal/video/processing"

    headers = {
        'Content-Type': 'application/json',
        'token': token,
        'yy': get_yy(payload, params, url=path),
    }

    logger.debug(headers['yy'])

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post("/v4/api/multimodal/video/processing", params=params, content=json.dumps(payload))
        response.raise_for_status()
        data = response.json()

        logger.debug(bjson(data))

        urls = json_path(data, "$..downloadURL") or []

        return urls


@alru_cache(ttl=3600)
async def check_token(token, threshold: int = 30, **kwargs):
    if not isinstance(token, str):
        return await check_tokens(token, check_token)

    try:
        token = await get_access_token(token)
        headers = {
            "token": token
        }
        params = {}
        async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
            response = await client.get("/v1/api/user/equity", params=params)
            response.raise_for_status()
            data = response.json()

            logger.debug(bjson(data))

            return "Unlimited" in str(data) or "高级会员" in str(data)  # Unlimited
    except Exception as e:
        logger.error(e)
        logger.debug(token)
        return False


async def generate(request: ImageRequest):
    task_response = await create_task(request)
    for i in range(1, 10):
        await asyncio.sleep(max(10 / i, 1))
        if urls := await get_task(task_response.task_id, task_response.system_fingerprint):
            logger.debug(urls)

            return ImagesResponse(data=[{"url": url} for url in urls])


if __name__ == '__main__':  # 304752356930580482
    vip = True
    # vip = False
    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzI5NzAyMjIsInVzZXIiOnsiaWQiOiIyNDM3MTMyNTI3OTc2NDA3MDgiLCJuYW1lIjoi5bCP6J665bi9NzA4IiwiYXZhdGFyIjoiaHR0cHM6Ly9jZG4ueWluZ3NoaS1haS5jb20vcHJvZC91c2VyX2F2YXRhci8xNzA2MjY3MzY0MTY0NDA0MDc3LTE3MzE5NDU3MDY2ODk2NTg5Nm92ZXJzaXplLnBuZyIsImRldmljZUlEIjoiMjQzNzEzMjUyNTQ1OTg2NTYyIiwiaXNBbm9ueW1vdXMiOnRydWV9fQ.X3KW00hAhSMk1c7DrXWYR27BROHNbfSiHD7Y-aweA6o"
    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM1NjMzNTIsInVzZXIiOnsiaWQiOiIyMjkwODQ3NTA2MDEzODgwMzciLCJuYW1lIjoi5bCP6J665bi9ODAzNyIsImF2YXRhciI6Imh0dHBzOi8vY2RuLnlpbmdzaGktYWkuY29tL3Byb2QvdXNlcl9hdmF0YXIvMTcwNjI2NzcxMTI4Mjc3MDg3Mi0xNzMxOTQ1NzA2Njg5NjU4OTZvdmVyc2l6ZS5wbmciLCJkZXZpY2VJRCI6IjMwNzIzNzc4MjU1NjE0NzcxMyIsImlzQW5vbnltb3VzIjpmYWxzZX19.MzZA9tW0YG2WFRWSkdD6bpEQt_0I-uIrxPJjxisKRNk"
    # 海外
    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM4MDQwOTksInVzZXIiOnsiaWQiOiIzMDc5OTkyOTg5MDAwNzA0MDUiLCJuYW1lIjoiRGF2aWQgUGhpbGxpcHMiLCJhdmF0YXIiOiIiLCJkZXZpY2VJRCI6IiJ9fQ.wmmDC7XBmmlQvcPM5TpdGVQDQDIkMpF9nkYBSB7UBWw"
    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM1NjQ5NDYsInVzZXIiOnsiaWQiOiIzMDQ3NjQzOTU5NDEwOTMzNzYiLCJuYW1lIjoiTWFyaWEiLCJhdmF0YXIiOiIiLCJkZXZpY2VJRCI6IiJ9fQ.QYLSWMj85hB43blHcrfSNBYJ2v_gFmQO9DmIYC5sVuQ"

    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM1NDgxMzUsInVzZXIiOnsiaWQiOiIzMDI4MzM4Njc3NzE5NDkwNTgiLCJuYW1lIjoibWUgYmV0dGVyIiwiYXZhdGFyIjoiaHR0cHM6Ly9saDMuZ29vZ2xldXNlcmNvbnRlbnQuY29tL2EvQUNnOG9jSWdTU0NoczFENHNUajFTVGs3UHNUbTd5NTNKRFg5OW84QnhwWmNWNjU2MEFKYlJnPXM5Ni1jIiwiZGV2aWNlSUQiOiIifX0.b8lAlOd961nVrJunpW9tRAEETe6VwlEXvf7y2faNCeY"
    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM0MDY1MzUsInVzZXIiOnsiaWQiOiIzMDI4MzM4Njc3NzE5NDkwNTgiLCJuYW1lIjoibWUgYmV0dGVyIiwiYXZhdGFyIjoiaHR0cHM6Ly9saDMuZ29vZ2xldXNlcmNvbnRlbnQuY29tL2EvQUNnOG9jSWdTU0NoczFENHNUajFTVGs3UHNUbTd5NTNKRFg5OW84QnhwWmNWNjU2MEFKYlJnPXM5Ni1jIiwiZGV2aWNlSUQiOiIifX0.mcozMacSciz0MORdleOMS_uhrixhIlpQmFmUwvn81I4"
    # arun(get_access_token(token, vip=vip))
    # arun(get_request_policy(token, vip=vip))
    # arun(get_access_token(vip=False))

    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM4MDQwOTksInVzZXIiOnsiaWQiOiIzMDc5OTkyOTg5MDAwNzA0MDUiLCJuYW1lIjoiRGF2aWQgUGhpbGxpcHMiLCJhdmF0YXIiOiIiLCJkZXZpY2VJRCI6IiJ9fQ.wmmDC7XBmmlQvcPM5TpdGVQDQDIkMpF9nkYBSB7UBWw"

    # p = "/Users/betterme/PycharmProjects/AI/MeUtils/meutils/data/cowboy-hat-face.webp"
    # arun(upload(Path(p).read_bytes(), token=token, vip=vip))
    # arun(upload(Path(p).read_bytes(), vip=False))
    # access_token = arun(get_access_token())
    # arun(upload(Path("img.png").read_bytes(), token=access_token))
    # arun(upload(Path("img.png").read_bytes(), token=access_token))

    # arun(get_task(task_id="307137575113703427", token=token)) # 307173162217783304
    # arun(get_task(task_id="307148849188945924", token=token))

    # arun(get_task(task_id="307267574751313927", token=token))

    # arun(get_task(task_id="307177115102699528", token=token))

    token = None
    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NzIyODE1NzcsInVzZXIiOnsiaWQiOiI0NDQyMjk2MDAzMzA0OTgwNTUiLCJuYW1lIjoibWZ1aiBiamhuIiwiYXZhdGFyIjoiIiwiZGV2aWNlSUQiOiIzMzkxMTQ5Mjg4NjU1Mjk4NjQiLCJpc0Fub255bW91cyI6ZmFsc2V9fQ.__NDyZQQqyYb7TLrumo944EfuCmrbzYngQloNBK4CmM"
    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NDg3Mzg4MTQsInVzZXIiOnsiaWQiOiIyMjkwODQ3NTA2MDEzODgwMzciLCJuYW1lIjoi5bCP6J665bi9ODAzNyIsImF2YXRhciI6Imh0dHBzOi8vY2RuLmhhaWx1b2FpLmNvbS9wcm9kL3VzZXJfYXZhdGFyLzE3MDYyNjc3MTEyODI3NzA4NzItMTczMTk0NTcwNjY4OTY1ODk2b3ZlcnNpemUucG5nIiwiZGV2aWNlSUQiOiIyNDM3MTMyNTI1NDU5ODY1NjIiLCJpc0Fub255bW91cyI6ZmFsc2V9fQ.o0SoZMSTWkXNHxJjt3Ggby5MJWSfd-rnK_I95T_WMP8"
    request = ImageRequest(
        model="hailuo-image-01",

        prompt="a cat",  # 307145017365086216
        # prompt="https://oss.ffire.cc/files/kling_watermark.png 哭起来",
        # first_frame_image="https://oss.ffire.cc/files/kling_watermark.png"  # 307173162217783304
    )

    r = arun(create_task(request, token=token))
    # arun(get_task(task_id=r.task_id, token=r.system_fingerprint))

    # arun(get_access_token(token))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : __init__.py
# @Time         : 2021/1/20 6:02 下午
# @Author       : yuanjie
# @Email        : meutils@qq.com
# @Software     : PyCharm
# @Description  : 




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : embedding_polt
# @Time         : 2023/5/9 15:43
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
import numpy as np
import pandas as pd
from openTSNE import TSNE
import plotly.graph_objs as go
import matplotlib.pyplot as plt
import matplotlib.colors as mcolors
from sklearn.decomposition import PCA
from scipy.optimize import linear_sum_assignment


class EmbeddingPlot(object):
    '''Class TSNE_Plot
    Method
    __init__
        input:
            sentence: List[string]
                用于展示的语句，应当是一个字符串的list
            embed: array
                用于计算相似度的embedding，应当是np.array(float), 或者tensor(float)等可以直接进行矩阵乘法的array
            label: [optional] List
                用于标注不同颜色的label，应当是一个list，对应每个sentence的label。如果没有提供label，将会自动调用聚类算法对sentence进行分类，默认的类别为3类
            n_clusters: [optional] int
                用于聚类算法的类别数量
            n_annotation_posisions: [optional] int
                展示的语句总数，默认为20句
    tsne_plot
        input:
            n_annotation_posisions: [optional] int
                展示的语句总数，默认为20句
            return_fig: [optional] boolean
                是否返回图像对象，如果为False，将直接绘制图像，如果为True，将返回图像对象，默认为False
        Output:
            若return_fig为True，将返回图像对象


    '''

    def __init__(self, sentence, embed, label=None, n_clusters: int = 3, n_annotation_positions: int = 20):
        assert n_clusters > 0, "N must be greater than 0"
        self.N = n_clusters
        self.test_X = pd.DataFrame({"text": sentence, "embed": [np.array(i) for i in embed]})
        self.test_y = pd.DataFrame({'label': label}) if label is not None else pd.DataFrame({"label": self.cluster()})
        self.embed = self.calculate_tsne()
        self.init_df()

        self.n_annotation_positions = n_annotation_positions
        self.show_sentence = []
        self.random_sentence()

        self.annotation_positions = []
        self.get_annotation_positions()
        self.mapping = {}

    def cluster(self):
        from sklearn.cluster import KMeans
        n_components = min(50, len(self.test_X))
        pca = PCA(n_components=n_components)
        compact_embedding = pca.fit_transform(np.array(self.test_X["embed"].tolist()))
        kmeans = KMeans(n_clusters=self.N)
        kmeans.fit(compact_embedding)
        labels = kmeans.labels_
        return labels

    def generate_colormap(self, n_labels):
        # 创建一个均匀分布的颜色映射
        color_norm = mcolors.Normalize(vmin=0, vmax=len(n_labels) - 1)
        # 使用 plt.cm 中预先定义的colormap，你可以自由选择其他colormap如"hsv", "hot", "cool", "viridis"等
        scalar_map = plt.cm.ScalarMappable(norm=color_norm, cmap='jet')

        colormap = {}
        for label in range(len(n_labels)):
            # 将颜色值转换为十六进制
            color_hex = mcolors.to_hex(scalar_map.to_rgba(label))
            colormap[n_labels[label]] = color_hex
        return colormap

    def divide_hex_color_by_half(self, hex_color):
        if len(hex_color) > 0 and hex_color[0] == "#":
            hex_color = hex_color[1:]

        red_hex, green_hex, blue_hex = hex_color[0:2], hex_color[2:4], hex_color[4:6]

        red_half = int(red_hex, 16) // 10 + (255 - 25)
        green_half = int(green_hex, 16) // 10 + (255 - 25)
        blue_half = int(blue_hex, 16) // 10 + (255 - 25)

        half_hex_color = "#{:02x}{:02x}{:02x}".format(red_half, green_half, blue_half)
        return half_hex_color

    def get_annotation_positions(self):
        min_x, max_x = self.df['x'].min() - 1, self.df['x'].max() + 2
        n = self.n_annotation_positions

        y_min, y_max = self.df['y'].min() * 3, self.df['y'].max() * 3

        add = 0 if n % 2 == 0 else 1
        y_values = np.linspace(y_min, y_max, n // 2 + add)

        left_positions = [(min_x, y) for y in y_values]
        right_positions = [(max_x, y) for y in y_values]

        self.annotation_positions = left_positions + right_positions

    def euclidean_distance(self, p1, p2):
        return np.sqrt((p1[0] - p2[0]) ** 2 + (p1[1] - p2[1]) ** 2)

    def map_points(self):
        # Get points from the dataframe using the show_sentence indices
        points1 = [(self.embed[i][0], self.embed[i][1]) for i in self.show_sentence]

        # Create a distance matrix between the points
        distance_matrix = np.zeros((len(points1), len(self.annotation_positions)))

        for i, point1 in enumerate(points1):
            for j, point2 in enumerate(self.annotation_positions):
                distance_matrix[i, j] = self.euclidean_distance(point1, point2)

        # Apply linear_sum_assignment to find the optimal mapping
        row_ind, col_ind = linear_sum_assignment(distance_matrix)

        for i, j in zip(row_ind, col_ind):
            self.mapping[self.show_sentence[i]] = self.annotation_positions[j]

    def show_text(self, show_sentence, text):
        sentence = []
        for i in range(len(text)):
            if i in show_sentence:
                s = text[i][:10] + "..." + text[i][-10:]
                sentence.append(s)
            else:
                sentence.append("")
        return sentence

    def init_df(self):
        X, Y = np.split(self.embed, 2, axis=1)
        data = {
            "x": X.flatten(),
            "y": Y.flatten(),
        }

        self.df = pd.DataFrame(data)

    def format_data(self):
        sentence = self.show_text(self.show_sentence, self.test_X["text"])
        X, Y = np.split(self.embed, 2, axis=1)
        n = len(self.test_X)
        data = {
            "x": X.flatten(),
            "y": Y.flatten(),
            "label": self.test_y["label"],
            "sentence": sentence,
            "size": [20 if i in self.show_sentence else 10 for i in range(n)],
            "pos": [{"x_offset": self.mapping.get(i, (0, 0))[0], "y_offset": self.mapping.get(i, (0, 0))[1]} for i in
                    range(n)],
            "annotate": [True if i in self.show_sentence else False for i in range(n)],
        }
        self.df = pd.DataFrame(data)

    def calculate_tsne(self):
        embed = np.array(self.test_X["embed"].tolist())
        n_components = min(50, len(self.test_X))
        pca = PCA(n_components=n_components)
        compact_embedding = pca.fit_transform(embed)
        tsne = TSNE(
            perplexity=30,
            metric="cosine",
            n_jobs=8,
            random_state=42,
            verbose=False,
        )
        embedding_train = tsne.fit(compact_embedding)
        embedding_train = embedding_train.optimize(n_iter=1000, momentum=0.8)
        return embedding_train

    def random_sentence(self):
        # 多次随机可能会影响可视化结果
        n_samples = len(self.test_y)

        show_sentence = []
        while len(show_sentence) < self.n_annotation_positions:
            show_sentence.append(np.random.randint(0, n_samples))
            show_sentence = list(set(show_sentence))

        # 确保每个标签至少有一个句子，用在show_sentence中最多的标签的句子来补充
        label_count = self.test_y["label"].value_counts()
        max_label = label_count.index[0]
        max_count = label_count[0]
        for i in range(max_count):
            for j in range(len(label_count)):
                if label_count[j] == i:
                    show_sentence.append(self.test_y[self.test_y["label"] == label_count.index[j]].index[0])
        self.show_sentence = list(set(show_sentence))

    def plot(self, return_fig=False):
        min_x, max_x = self.df['x'].min() - 1, self.df['x'].max() + 2
        fig = go.Figure()
        fig = go.Figure(layout=go.Layout(
            autosize=False,  # 禁止图像自动调整大小
            height=800,  # 您可以根据需要调整这个值
            width=1500,  # 您可以根据需要调整这个值
            # plot_bgcolor="#262626",
        ))

        label_colors = self.generate_colormap(self.df['label'].unique())

        line_legend_group = "lines"

        # 为每个类别的点创建散点图
        for label, color in label_colors.items():
            mask = self.df["label"] == label
            fig.add_trace(go.Scatter(x=self.df[mask]['x'], y=self.df[mask]['y'], mode='markers',
                                     marker=dict(color=color, size=self.df[mask]['size']),  # 添加 size 参数
                                     showlegend=True, legendgroup=line_legend_group,
                                     name=str(label))
                          )

        # 为每个句子创建注释
        for x, y, label, sentence, pos, annotate in zip(self.df.x, self.df.y, self.df.label, self.df.sentence,
                                                        self.df.pos, self.df.annotate):
            if not sentence:
                continue
            if not annotate:
                continue
            # pos在左边
            criteria = (pos["x_offset"] - min_x) < 1e-2

            sentence_annotation = dict(
                x=pos["x_offset"],
                y=pos["y_offset"],
                xref="x",
                yref="y",
                text=sentence,
                showarrow=False,
                xanchor="right" if criteria else 'left',
                yanchor='middle',
                font=dict(color="black"),
                bordercolor=label_colors.get(label, "black"),
                borderpad=2,
                bgcolor=self.divide_hex_color_by_half(label_colors.get(label, "black"))
            )
            fig.add_annotation(sentence_annotation)

            x_start = x - 1 if criteria else x + 1
            x_turn = x - 0.5 if criteria else x + 0.5
            y_turn = y

            fig.add_trace(
                go.Scatter(x=[pos["x_offset"], x_start, x_turn, x], y=[pos["y_offset"], pos["y_offset"], y_turn, y],
                           mode='lines',
                           line=dict(color=label_colors.get(label, "black")), showlegend=False,
                           legendgroup=line_legend_group))

        # 取消坐标轴的数字
        fig.update_xaxes(tickvals=[])
        fig.update_yaxes(tickvals=[])

        if not return_fig:
            fig.show()
        else:
            return fig

    def tsne_plot(self, n_sentence=20, return_fig=False):
        # 计算t-SNE，返回降维后的数据，每个元素为一个二维向量
        embedding_train = self.calculate_tsne()

        # 随机抽取显示文本, n为抽取的数量，show_sentence为一个列表，每个元素为显示文本的索引
        if self.n_annotation_positions != min(n_sentence, len(self.test_y)):
            self.n_annotation_positions = min(n_sentence, len(self.test_y))
            self.random_sentence()
            self.get_annotation_positions()

        # find the optimal sentence positions
        self.map_points()

        # 格式化数据，输出为一个pandas的DataFrame，包含x, y, label, sentence, sentence_pos, size
        # x, y为降维后的坐标，label为类别，sentence为显示的文本，sentence_pos为文本的位置("left", "right")，size为被选中文本的大小
        self.format_data()
        # self.df = self.df.sort_values('y').reset_index(drop=True)

        if not return_fig:
            # 绘制图像
            self.plot()
        else:
            return self.plot(return_fig=return_fig)


if __name__ == '__main__':
    tp = EmbeddingPlot(['a', 'b', 'c', 'd']*10, np.random.random((40, 128)))
    tp.tsne_plot()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : utils
# @Time         : 2025/12/29 16:12
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *


def getali231():
    file = get_resolve_path('../../data/apis/fireyejs.js', __file__)
    # node执行231.js
    res = subprocess.run(['node', file], capture_output=True, text=True)
    # logger.debug(res)

    ali231 = re.search(r'###(.*?)###', res.stdout).group(1)
    # print(ali231)
    return ali231


if __name__ == '__main__':
    print(getali231())

    # import execjs
    # import pathlib
    #
    # # 1. 读取 JS 源码（包含 code.js 和 fireyejs.js 合并后的完整代码）
    # js_code = pathlib.Path("fireyejs.js").read_text(encoding="utf-8")
    #
    #
    #
    # # 2. 初始化运行环境
    # ctx = execjs.compile(js_code)
    #
    # # 3. 调用函数
    # ali231 = ctx.call("getToken")
    # print("ali231 =", ali231)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : reranker
# @Time         : 2024/8/13 10:08
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from meutils.schemas.siliconflow_types import BASE_URL, RerankRequest, EXAMPLES
from meutils.config_utils.lark_utils import get_spreadsheet_values, get_next_token_for_polling

FEISHU_URL = 'https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=InxiCF'


@alru_cache()
async def rerank(request: RerankRequest, api_key: Optional[str] = None):
    api_key = api_key or await get_next_token_for_polling(feishu_url=FEISHU_URL)

    payload = request.model_dump()
    payload['model'] = "BAAI/bge-reranker-v2-m3"  # 写死

    headers = {
        "authorization": f"Bearer {api_key}"
    }
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=100) as client:
        response = await client.post("/rerank", json=payload)
        # logger.debug(response.text)

        if response.is_success:
            return response.json()
        else:
            response.raise_for_status()


if __name__ == '__main__':
    arun(rerank(RerankRequest(**EXAMPLES[0])))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : images
# @Time         : 2025/11/23 23:27
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.llm.openai_utils import to_openai_params
from meutils.schemas.image_types import ImageRequest, ImagesResponse
from openai import AsyncOpenAI


async def generate(request: ImageRequest, api_key: str = None, base_url: str = None):
    base_url = base_url or "https://api.aimlapi.com/v1"
    client = AsyncOpenAI(
        api_key=api_key,
        base_url=base_url,
    )
    logany(request)

    extra_body = {"num_images": request.n, "image_urls": None}
    if request.image_urls:
        extra_body['image_urls'] = request.image_urls

        if request.model.startswith(('google/gemini')):
            request.model = f"{request.model.strip('-edit')}-edit"

    data = to_openai_params(request)
    data["extra_body"] = {**data['extra_body'], **extra_body}

    logany(bjson(data))

    response = await client.images.generate(**data)
    logany(response)

    return response


if __name__ == "__main__":
    # main()

    api_key = "96f845c6e4664ba2bfa65aa1111693f5"

    data = {
        "prompt": "带个墨镜",
        "model": "google/gemini-3-pro-image-preview",
        "image_urls": [
            "https://s3.ffire.cc/files/jimeng.jpg",
        ],
        "aspect_ratio": "2:3"
    }

    data = {
        "model": "klingai/image-o1",
        "prompt": "Combine the images so the T-Rex is wearing a business suit, sitting in a cozy small café, drinking from the mug. Blur the background slightly to create a bokeh effect.",
        # "image": [
        #     "https://raw.githubusercontent.com/aimlapi/api-docs/main/reference-files/t-rex.png",
        #     "https://raw.githubusercontent.com/aimlapi/api-docs/main/reference-files/blue-mug.jpg",
        # ],
    }

    request = ImageRequest(**data)

    arun(generate(request, api_key))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : openai_files
# @Time         : 2025/3/4 18:20
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.io.files_utils import to_bytes
from meutils.llm.clients import moonshot_client, zhipuai_client


async def file_extract(file):  # "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf"
    """todo 定时删除文件"""
    filename = Path(file).name
    mime_type, _ = mimetypes.guess_type(filename)  # mime_type = "application/octet-stream"
    file: bytes = await to_bytes(file)

    file_object = await moonshot_client.files.create(
        # file=file,
        # file=("filename.pdf", file),
        file=(filename, file, mime_type),

        purpose="file-extract"
    )
    logger.debug(file_object)

    response = await moonshot_client.files.content(file_id=file_object.id)
    return response.text



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : pos_tagging
# @Time         : 2023/4/23 12:28
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from paddlenlp import Taskflow


@lru_cache()
class Ner(object):

    def __init__(self, mode='fast', batch_size=8, entity_only=False, device=None, filter_func=None, model=None,
                 show_bar=False):
        """

        :param mode:
            fast lac
            accurate wordtag 解语
        :param filter_func: lambda w2t: w2t[1].startswith(('n', 'PER')) # word2tag
        :param batch_size:
        :param entity_only:
        :param device:
        :param model:
        ---
        pip install 'protobuf<4,>=3.20.2' -U


        """
        self.batch_size = max(batch_size, 2)
        self.filter_func = filter_func
        self.show_bar = show_bar

        self.task_flow = Taskflow(
            task='ner',
            model=model,
            mode=mode,
            device=device,
            batch_size=batch_size,
            entity_only=entity_only
        )

    def __call__(self, texts):
        results = texts | xbar4iter(self._task_flow, self.batch_size, show_bar=self.show_bar)
        if self.filter_func:  # 每一条都过滤
            results = results | xmap_(lambda w2ts: w2ts | xfilter_(self.filter_func))

        return results

    def _task_flow(self, texts):
        if isinstance(texts, str):
            texts = [texts]

        _ = self.task_flow(texts)
        if len(texts) == 1:
            return [_]
        return _
    # def _task_flow(self, texts):
    #     _ = self.task_flow(texts)
    #     if isinstance(texts, str) or len(texts) == 1:
    #         return [_]
    #     return _
    # 名词标注 https://github.com/PaddlePaddle/PaddleNLP/blob/develop/docs/model_zoo/taskflow.md#%E8%A7%A3%E8%AF%AD%E7%9F%A5%E8%AF%86%E6%A0%87%E6%B3%A8
    # >>> from paddlenlp import Taskflow
    # >>> nptag = Taskflow("knowledge_mining", model="nptag")
    # >>> nptag("糖醋排骨")
    # [{'text': '糖醋排骨', 'label': '菜品'}]


if __name__ == '__main__':
    # print(Ner('accurate')(['周杰伦是个音乐家'] * 10))
    filter_func = lambda w2t: w2t[1].startswith(('n', 'PER'))
    print(Ner('fast', filter_func=filter_func)(['周杰伦是个音乐家'] * 2))
    print(Ner('fast')('周杰伦是个音乐家'))
    print(Ner('fast')(['周杰伦是个音乐家']))
    print(Ner('accurate')(['周杰伦是个音乐家']))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2026/1/16 11:23
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://bailian.console.aliyun.com/cn-beijing/?tab=api&accounttraceid=01bd0ba7095b400185920afa50d3ede3nmpi#/api/?type=model&url=2867393

from meutils.pipe import *
from openai import AsyncOpenAI
from meutils.schemas.video_types import SoraVideoRequest, Video

"""

curl --location 'https://dashscope.aliyuncs.com/api/v1/services/aigc/video-generation/video-synthesis' \
    -H 'X-DashScope-Async: enable' \
    -H "Authorization: Bearer $DASHSCOPE_API_KEY" \
    -H 'Content-Type: application/json' \
    -d '{
    "model": "wan2.6-i2v",
    "input": {
        "prompt": "一幅都市奇幻艺术的场景。一个充满动感的涂鸦艺术角色。一个由喷漆所画成的少年，正从一面混凝土墙上活过来。他一边用极快的语速演唱一首英文rap，一边摆着一个经典的、充满活力的说唱歌手姿势。场景设定在夜晚一个充满都市感的铁路桥下。灯光来自一盏孤零零的街灯，营造出电影般的氛围，充满高能量和惊人的细节。视频的音频部分完全由他的rap构成，没有其他对话或杂音。",
        "img_url": "https://help-static-aliyun-doc.aliyuncs.com/file-manage-files/zh-CN/20250925/wpimhv/rap.png",
        "audio_url": "https://help-static-aliyun-doc.aliyuncs.com/file-manage-files/zh-CN/20250925/ozwpvi/rap.mp3"
    },
    "parameters": {
        "resolution": "720P",
        "prompt_extend": true,
        "duration": 10,
        "audio": true,
        "shot_type":"multi"
    }
}'

curl --location --request GET 'https://dashscope.aliyuncs.com/api/v1/tasks/{task_id}' \
--header "Authorization: Bearer $DASHSCOPE_API_KEY"


"""
BASE_URL = "https://dashscope.aliyuncs.com/api/v1"
BASE_URL = "https://dashscope-intl.aliyuncs.com/api/v1"


# generate_audion
class Tasks(object):

    def __init__(self, base_url: Optional[str] = None, api_key: str = None):
        self.client = AsyncOpenAI(base_url=BASE_URL, api_key=api_key)

    async def create(self, request: SoraVideoRequest):
        payload = {
            "model": request.model,
            "input": {
                "prompt": request.prompt,
                # "img_url": "https://help-static-aliyun-doc.aliyuncs.com/file-manage-files/zh-CN/20250925/wpimhv/rap.png",
                # "audio_url": "https://help-static-aliyun-doc.aliyuncs.com/file-manage-files/zh-CN/20250925/ozwpvi/rap.mp3"
            },
            "parameters": {
                # "resolution": "720P",
                "prompt_extend": True,
                # "duration": 10,
                # "audio": true,
                # "shot_type": "multi"
            }
        }
        # parameters
        if request.seconds:
            payload["parameters"]["duration"] = int(request.seconds)

        if request.resolution:
            payload["parameters"]["resolution"] = request.resolution

        if request.shot_type:
            payload["parameters"]["shot_type"] = request.shot_type

        # 参考图
        if request.input_reference:
            payload['input']['img_url'] = request.input_reference

        if image_urls := request.input_reference:
            payload['model'] = request.model.replace("text-to-video", "image-to-video").replace("t2v", "i2v")

            payload['input']['img_url'] = image_urls[0]


        else:
            payload['model'] = request.model.replace("image-to-video", "text-to-video").replace("i2v", "t2v")

        # 首尾帧
        if request.first_frame_image:
            payload['input']['first_frame_url'] = request.first_frame_image

        if request.last_frame_image:
            payload['input']['last_frame_url'] = request.last_frame_image

        if request.video:
            if request.model.startswith(("alibaba/wan-2-6",)):
                payload["video_urls"] = [request.video]
                payload['model'] = "alibaba/wan-2-6-r2v"

            else:
                payload["video_url"] = request.video
                payload['keep_audio'] = True

                if request.model.endswith('edit'):  # kling
                    payload['model'] = "klingai/video-o1-video-to-video-edit"
                else:
                    payload['model'] = "klingai/video-o1-video-to-video-reference"

        logany(bjson(payload))

        response = await self.client.post(
            path="/video/generations",
            body=payload,
            cast_to=object
        )
        """
        {
    "id": "9913239d-4fa8-47ea-b51d-d313e29caba5:alibaba/wan2.5-i2v-preview",
    "status": "queued",
    "meta": {
        "usage": {
            "tokens_used": 105000
        }
    }

    {
    "generation_id": "339995387916622:minimax/hailuo-02",
    "status": "queued",
    "meta": {
        "usage": {
            "tokens_used": 588000
        }
    }
}
}
        """

        logger.debug(bjson(response))

        return response

    async def get(self, task_id: str):
        logger.debug(task_id)

        response = await self.client.get(
            path=f"/video/generations?generation_id={task_id}",
            cast_to=object
        )
        """
        {
    "id": "9913239d-4fa8-47ea-b51d-d313e29caba5:alibaba/wan2.5-i2v-preview",
    "status": "completed",
    "video": {
        "url": "https://cdn.aimlapi.com/alpaca/1d/dd/20251107/30b07d9c/42740107-9913239d-4fa8-47ea-b51d-d313e29caba5.mp4?Expires=1762593280&OSSAccessKeyId=LTAI5tBLUzt9WaK89DU8aECd&Signature=Guk6apyEnKeuniLv0mcBJhkHO%2FI%3D"
    }
}

{
    "id": "",
    "status": "unknown",
    "error": {
        "name": "Error",
        "message": "invalid params, task_id cannot by empty"
    }
}

        """
        logger.debug(bjson(response))

        status = response
        if response.get('error'):
            status = 'failed'

        video = Video(
            id=task_id,
            status=status,
            video_url=(response.get("video") or {}).get("url"),

            error=response.get("error")
        )

        # logger.debug(bjson(video))

        return video



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : to_db
# @Time         : 2025/8/26 17:08
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import json

from meutils.pipe import *
from meutils.db.redis_db import redis_client
import os
from redis import Redis, ConnectionPool
from redis.asyncio import Redis as AsyncRedis, ConnectionPool as AsyncConnectionPool

# kwargs = {
#     "retry_on_timeout": True,
#     # "db": 6
# }
# REDIS_URL="redis://:chatfirechatfire@110.sdsd.51.201:6379" # 'redis://localhost:10/1?pool_max_size=1'
#     # logger.debug(REDIS_URL)
#
# pool = ConnectionPool.from_url(REDIS_URL, **kwargs)
# redis_client_main = Redis.from_pool(pool)

data = json.loads(open('FeHelper-20250826164705.json').read())





ids = list(set([item['task_id'] for item in data['data']['items']]))

#
#
# for id in ids:
#     if v := redis_client.get(id):
#         redis_client_main.set(id, v)
#
#
# redis_client_main.get("cgt-20250826155618-nrzxm")





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : common
# @Time         : 2023/5/18 16:39
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *


def doc2docx(doc_paths, outdir='.', max_workers=1):
    """todo: 多进程阻塞"""
    if isinstance(doc_paths, str):
        doc_paths = [doc_paths]
    max_workers = min(max_workers, len(doc_paths))
    func = partial(_doc2docx, outdir=outdir)
    return doc_paths | xProcessPoolExecutor(func, max_workers) | xlist


def _doc2docx(doc_path, outdir='.'):
    if Path(doc_path).is_file():
        cmd = 'libreoffice --headless --convert-to docx'.split() + [doc_path, '--outdir', outdir]
        p = subprocess.Popen(cmd, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
        p.wait(timeout=16)
        stdout, stderr = p.communicate()
        if stderr:
            raise subprocess.SubprocessError(stderr)
        return stdout.decode()
    return False


def stream2tempfile4process(
        stream: Union[str, bytes] = b"temp",
        process_fn: Callable[[os.PathLike], Any] = lambda p: p.read_text(),
        delete=True
):
    # 创建临时文件
    import tempfile

    with tempfile.NamedTemporaryFile(delete=delete) as temp_file:
        p = Path(temp_file.name)
        if isinstance(stream, str):  # 写
            p.write_text(stream)
        else:
            p.write_bytes(stream)
        return process_fn(p)  # 读


def stream_parser(file_stream):
    """
        from fastapi import FastAPI, File, UploadFile

        file_stream = UploadFile(open(''))

        filename, file_stream = stream_parser(file_stream)
    """
    filename = ''
    # from fastapi import FastAPI, File, UploadFile
    if hasattr(file_stream, 'file'):
        filename = file_stream.file.name or file_stream.filename
        file_stream = file_stream.file
        if isinstance(file_stream, io.TextIOWrapper):  # 转 bytes
            file_stream = file_stream.buffer
        file_stream = file_stream.read()

    # st.file_uploader
    elif hasattr(file_stream, 'read'):
        filename = file_stream.name
        if isinstance(file_stream, io.TextIOWrapper):  # 转 bytes
            file_stream = file_stream.buffer
        file_stream = file_stream.read()

    # ValueError: I/O operation on closed file.
    # with file_stream:
    #     file_stream = file_stream.buffer.read()

    elif (
            isinstance(file_stream, (str, os.PathLike))
            and len(file_stream) < 256
            and Path(file_stream).is_file()
    ):
        filename = str(file_stream)
        file_stream = open(filename).read()

    elif isinstance(file_stream, (bytes, bytearray)):
        pass

    return filename, file_stream



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : x
# @Time         : 2024/9/20 17:59
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *

from meutils.config_utils.lark_utils import aget_spreadsheet_values, get_next_token_for_polling



if __name__ == '__main__':
    feishu_url = 'https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=hxVlQw'
    d = arun(aget_spreadsheet_values(feishu_url=feishu_url, to_dataframe=True))
    # d = arun(aget_spreadsheet_values(feishu_url=feishu_url))









#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : auth
# @Time         : 2023/12/19 17:12
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 
# todo: 按模型取 key 免费模型可以写死在redis里，付费模型可以从feishu里取
import numpy as np
from typing import Optional, Union

from fastapi.security import HTTPBearer, HTTPAuthorizationCredentials
from fastapi import Depends, HTTPException, status

from meutils.config_utils.lark_utils import get_series, get_next_token

http_bearer = HTTPBearer()


# 定义获取token的函数
async def parse_token(token: str) -> Optional[str]:
    if token is None: return None

    # 前处理
    base_url = None
    if '|' in token:
        base_url, token = token.split('|', maxsplit=1)

    if token.startswith('redis:'):  # redis里按序轮询
        if "feishu.cn" in token:  # redis:https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=Y7HVfo
            feishu_url = token.removeprefix("redis:")
            token = await get_next_token(feishu_url, ttl=24 * 3600)

            # logger.debug(token)

        else:  # redis:token1,token2
            tokens = token.removeprefix("redis:").split(',')  # todo: 初始化redis
            token = np.random.choice(tokens)

    elif token.startswith("feishu:") and "feishu.cn" in token:  # feishu 随机 feishu:https://
        feishu_url = token.removeprefix("feishu:")
        tokens = await get_series(feishu_url)
        token = np.random.choice(tokens)

    elif token.startswith("http") and "feishu.cn" in token:  # feishu 取所有 keys 主要针对 channel todo: channel:https://
        feishu_url = token
        tokens = await get_series(feishu_url, duplicated=True)
        token = '\n'.join(tokens)  # 多渠道
    elif token.startswith("channel:") and "feishu.cn" in token:  # channel 全部 channel:https://
        feishu_url = token.removeprefix("channel:")

        tokens = await get_series(feishu_url, duplicated=True)
        token = '\n'.join(tokens)  # 多渠道

    elif ',' in token:  # 内存里随机轮询
        token = np.random.choice(token.split(','))

    elif token in {"None", "none", "null"}:
        token = None

    # 后处理
    if base_url:
        token = f"{base_url}|{token}"

    return token


async def get_bearer_token(
        auth: Optional[HTTPAuthorizationCredentials] = Depends(http_bearer)
) -> Optional[str]:
    """
    获取Bearer token
    :param auth: HTTP认证凭证
    :return: token字符串
    """
    if auth is None: return None

    return await parse_token(auth.credentials)


# async def get_next_token(redis_key):
#     """轮询"""
#     if api_key := await redis_aclient.lpop(redis_key):
#         await redis_aclient.rpush(redis_key, api_key)
#         return api_key


async def get_bearer_token_for_oneapi(
        auth: Optional[HTTPAuthorizationCredentials] = Depends(http_bearer)
) -> Optional[str]:
    """
    # todo: oneapi userinfo apikey info
    """
    if auth is None:
        return None

    token = auth.credentials

    return token


if __name__ == '__main__':
    from meutils.pipe import *

    # arun(parse_token("https://ai.gitee.com/v1/rerank|5PJFN89RSDN8CCR7CRGMKAOWTPTZO6PN4XVZV2FQ"))

    arun(parse_token("https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=Gvm9dt"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : log_utils
# @Time         : 2020/11/12 11:40 上午
# @Author       : yuanjie
# @Email        : meutils@qq.com
# @Software     : PyCharm
# @Description  :

# from loguru import logger
#
# logger.add(
#     '日志同步{time: YYYY_MM_DD}.log',
#     enqueue=True,  # 异步
#     encoding="utf-8",
#     backtrace=True,
#     diagnose=True,
#     rotation='00:00',
#     retention='7 days',
# )
import os
import sys
from random import uniform
from loguru import logger
from meutils.notice.wecom import Wecom


def melogger(sink=sys.stderr, **logkwargs):  # logger.add(print, enqueue=True)
    logger.remove()
    logger.add(sink, enqueue=True, **logkwargs)


# LOG CONF: 需提前配置在环境变量里, 其他参考loguru._defaults.LOGURU_*
LOG_PATH = os.getenv('LOG_PATH')  # todo： 装饰器

# todo: http://www.manongjc.com/detail/27-wpvjqkuysjaacig.html
# 1. 过滤
# 2. 默认配置、zk配置、文件配置、环境变量配置
if LOG_PATH:
    logger.add(
        LOG_PATH,
        rotation="100 MB",
        enqueue=True,  # 异步
        encoding="utf-8",
        backtrace=True,
        diagnose=True,
        # level=_defaults.LOGURU_LEVEL,
        # filter=_defaults.LOGURU_FILTER,
    )

else:
    logger.remove()
    logger.add(sys.stderr, enqueue=True)



# 日志采样输出：按时间 按条数
def logger4sample(log, bins=10):
    if uniform(0, bins) < 1:
        logger.info(log)


# todo: 起个服务配置通用logger
def logger4wecom(title='这是一个标题', text='这是一条log', hook_url=None):
    return Wecom(hook_url).send_markdown(title=str(title), content=str(text))


# todo:
#  add zk/es/mongo/hdfs logger
# logger = logger.patch(lambda r: r.update(name=__file__))
logger_patch = lambda name: logger.patch(lambda r: r.update(name=name))  # main模块: 等价于 __name__=__file__
# file_name, line, function, _, _ = inspect.getframeinfo(inspect.currentframe().f_back)
# logger = logger.patch(lambda r: r.update(name='func_test', function=function, line=line))
#
#
# from starlette_context import context
#
# def patcher_func(record):
#     user: Any = context.get("user")
#
#     if user is not None:
#         record["extra"].update(user=user["username"])
#
#
# logger.configure(**log_config, patcher=patcher_func)


if __name__ == '__main__':
    logger.info("xx")
    # logger4feishu('', 'a\nb')
    logger4wecom()

    # 异步sink

    import time, datetime
    from asgiref.sync import sync_to_async

    logger.remove()


    @sync_to_async(thread_sensitive=True)
    def sink(message):
        time.sleep(3)  # IO processing...
        print(message, end="")


    logger.add(sink, enqueue=True)


    def work():
        logger.info("Start")
        logger.info("End")
        return datetime.datetime.now()


    work()

    # 异步
    logger.remove()
    logger.add(print, enqueue=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : 表格抽取
# @Time         : 2023/7/17 18:14
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
import os
from dataclasses import dataclass
from typing import List
from collections import Counter

import pandas as pd
import pdfplumber
import tabulate


def extract_tables_with_text(pdf) -> List[str]:
    """抽取表格并嵌入文本"""

    def clean_cell_text(text):
        """
        清除文本中的换行符和多余空格
        """
        if text is None:
            return ""
        text = text.replace("\n", "")
        # 去除字符串开头和结尾的空白字符
        text = text.strip()
        return text

    def check_bboxes(word, table_bbox):
        left = word['x0'], word['top'], word['x1'], word['bottom']
        r = table_bbox
        return left[0] > r[0] and left[1] > r[1] and left[2] < r[2] and left[3] < r[3]

    def keep_visible_lines(obj):

        if obj['object_type'] == 'rect':
            return obj['non_stroking_color'] == 0
        return True

    lines = []
    page_counter = 0
    # 用来缓存没完整展示的表
    pending_table = []
    tp = None
    for page_number, page in enumerate(pdf.pages, start=0):
        p = page.filter(keep_visible_lines)
        combine_flag = len(pending_table) != 0
        page_counter = page_number
        tables = p.find_tables(
            table_settings={
                "vertical_strategy": "lines",
                "horizontal_strategy": "lines",
                # "explicit_vertical_lines": self.curves_to_edges(p.curves) + p.edges,
                # "explicit_horizontal_lines": self.curves_to_edges(p.curves) + p.edges,
            }
        )
        if len(tables) != 0:
            is_over_footer = p.chars[-1].get('y0') >= p.bbox[3] - p.find_tables()[-1].bbox[3]
        else:
            is_over_footer = False
        bboxes = [table.bbox for table in tables]
        tables = [{'table': i.extract(), 'top': i.bbox[1]} for i in tables]
        if is_over_footer:
            tp = pd.DataFrame(tables[-1]['table']).applymap(clean_cell_text)
            tables = tables[0:len(tables) - 1]
        non_table_words = [word for word in p.extract_words() if
                           not any([check_bboxes(word, table_bbox) for table_bbox in bboxes])]

        for cluster in pdfplumber.utils.cluster_objects(non_table_words + tables, 'top', tolerance=5):
            for c in cluster:
                if 'text' in c and c['text'] != str(page_number) and c['text'] != non_table_words[-1]:
                    lines.append("".join(c['text']))
                elif 'table' in c:
                    if combine_flag:
                        dt = pd.concat([pd.concat(pending_table, axis=0),
                                        pd.DataFrame(c['table']).applymap(clean_cell_text)], axis=0)
                        combine_flag = False
                        pending_table = []
                    else:
                        dt = pd.DataFrame(c['table']).applymap(clean_cell_text)
                    tb = tabulate.tabulate(dt, tablefmt="pipe", showindex=False, headers="keys")
                    lines.append(tb)
        if is_over_footer:
            pending_table.append(tp)
    content_counter = Counter(lines)
    return [word for word in content_counter if content_counter[word] != page_counter]


@dataclass
class Document:
    """文档结构"""
    text: List[str]
    source: str


def extract_text(filepath) -> Document:
    with pdfplumber.open(filepath) as pdf:
        text = extract_tables_with_text(pdf)
    return Document(text=text, source=os.path.basename(filepath))


if __name__ == '__main__':
    """
    pdfplumber==0.9.0
    tabulate[widechars]==0.9.0
    numpy==1.21.5
    pandas==2.0.3
    """
    doc = extract_text("/Users/betterme/Downloads/H2_AN202303301584686196_1.pdf")
    for line in doc.text:
        print(line)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : __init__.py
# @Time         : 2024/11/11 10:26
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *

NOTICE = get_resolve_path('./NOTICE.html', __file__).read_text()

FOOTER = get_resolve_path('./FOOTER.md', __file__).read_text()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : kimi_types
# @Time         : 2024/2/29 16:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *


class KimiData(BaseModel):
    """
    {"error":{"error_type":"openai.completion.stream","message":"Kimi 现在有点累了，晚一点再来问问我吧！","detail":"runtime error: invalid memory address or nil pointer dereference"},"event":"error"}

    data: {"content":"1+1","event":"req","group_id":"cljdett0tc12f8jcpc7g","id":"cljdett0tc12f8jcpc8g","refs":[]}
    data: {"event":"resp","group_id":"cljdett0tc12f8jcpc7g","id":"cljdett0tc12f8jcpc90"}
    data: {"event":"debug","message":{"need2search":false,"search_target":"","search_language":""}}
    data: {"event":"debug","message":{"need2search":true,"search_target":"南京今天天气","search_language":"zh-cn"}}
    data: {"event":"search_plus","msg":{"type":"start"}}
    data: {"event":"search_plus","msg":{"successNum":1,"title":"南京天气","type":"get_res","url":"http://m.nmc.cn/publish/forecast/AJS/nanjing.html"}}
        {'successNum': 1, 'title': '南京天气预报25天|南京未来25天天气|南京天气预报未来25天...', 'type': 'get_res', 'url': 'http://www.tqw1.com/jsnanjing_25.shtml'}
    data: {"event":"cmpl","text":" "}
    data: {"event":"cmpl","text":"1"}
    data: {"event":"cmpl","text":"å "}
    data: {"event":"done"}
    data: {"event":"cmpl","text":"1"}
    data: {"event":"cmpl","text":"ç­"}
    data: {"event":"cmpl","text":"äº"}
    data: {"event":"cmpl","text":"2"}
    data: {"event":"cmpl","text":"ã"}
    data: {"event":"all_done"}

    {"error":{"error_type":"openai.completion.token_length_too_long","message":"转眼间，你和 Kimi 的这个对话已经超过了 20 万字。Kimi 在不断提升自己对话最大长度，但现在只能麻烦你开启一个新会话。期待与你再相遇！"},"event":"error"}
    """
    event: str = 'cmpl'  # 事件类型 ping

    prompt: str = Field(default='', alias='content')
    content: str = Field(default='', alias='text')  # 生成的文本

    # id: Optional[str] = None
    # group_id: Optional[str] = None

    msg: dict = {}
    refs: Optional[List[str]] = None  # 文件问答

    # {"error_type":"auth.token.invalid","message":"您的授权已过期，请重新登录"}
    # {"error_type":"chat.forbidden","message":"此会话已被禁用"}
    error_type: Optional[str] = None
    message: Optional[Any] = None

    # todo
    # markdown


class Data(BaseModel):
    event: str = 'cmpl'  # 事件类型 ping

    prompt: str = Field(default='', alias='content')
    content: str = Field(default='', alias='text')  # 生成的文本

    # id: Optional[str] = None
    # group_id: Optional[str] = None

    msg: dict = {}
    refs: Optional[List[str]] = None  # 文件问答

    # {"error_type":"auth.token.invalid","message":"您的授权已过期，请重新登录"}
    # {"error_type":"chat.forbidden","message":"此会话已被禁用"}
    error_type: Optional[str] = None
    message: Optional[Any] = None

    # chunk
    markdown_data: str = ''

    def __init__(self, **data):
        super().__init__(**data)

        if self.event == 'search_plus':
            msg_type = self.msg.get("type")
            if msg_type:  # start_res
                title = self.msg.get("title")
                url = self.msg.get("url")
                self.markdown_data = f"""\n```{msg_type}\n{self.msg}\n```\n"""  # f"""- [🔗{title}]({url})\n"""



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : tryblend
# @Time         : 2024/9/4 09:22
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :


from meutils.pipe import *
from meutils.decorators.retry import retrying

from meutils.notice.feishu import send_message as _send_message
from meutils.db.redis_db import redis_client, redis_aclient
from meutils.config_utils.lark_utils import aget_spreadsheet_values, get_next_token_for_polling
from meutils.schemas.tryblend_types import BASE_URL, FEISHU_URL, FEISHU_URL_VIP
from meutils.schemas.tryblend_types import GPT_4O_MINI, GPT_4O, CHECK_PAYLOAD
from meutils.schemas.tryblend_types import CLAUDE_3_HAIKU, CLAUDE_3_SONNET, CLAUDE_3_OPUS, CLAUDE_35_SONNET
from meutils.schemas.tryblend_types import PERPLEXITY_SONAR_SMALL, PERPLEXITY_SONAR_LARGE, PERPLEXITY_SONAR_HUGE

from meutils.llm.openai_utils import to_openai_completion_params, token_encoder, token_encoder_with_cache
from meutils.schemas.openai_types import chat_completion, chat_completion_chunk, ChatCompletionRequest, CompletionUsage
from openai import OpenAI, AsyncOpenAI, APIStatusError

# from meutils.llm.openai_utils import create_chat_completion_chunk, create_chat_completion

send_message = partial(
    _send_message,
    url="https://open.feishu.cn/open-apis/bot/v2/hook/e0db85db-0daf-4250-9131-a98d19b909a9",
    title=__name__
)


class Completions(object):

    def __init__(self, api_key: Optional[str] = None, vip: bool = False):
        self.api_key = api_key
        self.vip = vip

    async def create(self, request: ChatCompletionRequest):
        if request.stream:
            return self.stream(request)
        else:
            content = ""
            completion_tokens = 0
            prompt_tokens = len(str(request.messages))
            async for chunk in self.stream(request):
                content += chunk
                completion_tokens += 1
            # logger.debug(content)
            chat_completion.choices[0].message.content = content
            chat_completion.usage = CompletionUsage(
                prompt_tokens=prompt_tokens,
                completion_tokens=completion_tokens,
                total_tokens=prompt_tokens + completion_tokens
            )
            return chat_completion

    async def stream(self, request: ChatCompletionRequest):
        token = self.api_key or await get_next_token_for_polling(
            feishu_url=FEISHU_URL_VIP if self.vip else FEISHU_URL,
            check_token=check_token
        )

        if request.model.startswith("gpt-4o-mini"):
            payload = GPT_4O_MINI
        elif request.model.startswith("gpt-4"):
            payload = GPT_4O

        elif request.model.startswith("claude-3-5-sonnet"):
            payload = CLAUDE_35_SONNET
        elif request.model.__contains__("haiku"):
            logger.debug(request.model)
            payload = CLAUDE_3_HAIKU
        elif request.model.__contains__("sonnet"):
            payload = CLAUDE_3_SONNET
        elif request.model.__contains__("opus"):
            payload = CLAUDE_3_OPUS

        elif request.model.startswith(("perplexity-sonar-huge",)):
            payload = PERPLEXITY_SONAR_HUGE
        elif request.model.startswith(("perplexity-sonar-large", "net-gpt-4",)):
            payload = PERPLEXITY_SONAR_LARGE
        elif request.model.startswith(("perplexity-sonar-small", "perplexity", "net", "meta",)):
            payload = PERPLEXITY_SONAR_SMALL

        else:
            payload = GPT_4O_MINI

        payload[0]['messages'] = request.messages

        headers = {
            'Cookie': token,
            'next-action': 'ca5ce500ddee37bddc3c986bee81b599f41e3efb',
        }

        async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=300) as client:
            async with client.stream(method="POST", url="", json=payload) as response:
                logger.debug(response.status_code)

                yield "\n"  # 提升首字速度

                async for chunk in response.aiter_lines():
                    # logger.debug(response.status_code)
                    logger.debug(chunk)  # {"error":{"message":"User not found","status":500}}

                    if 'Please add more credits to use this model' in chunk:
                        # send_message("tryblend 余额不足")
                        # logger.debug(chunk)
                        break

                    if chunk and (chunk := chunk.split(":", maxsplit=1)[-1]).strip() and chunk.startswith("{"):

                        try:
                            chunk = json.loads(chunk)
                            chunk = chunk.get('diff', [""])[-1] or chunk.get('curr', "")
                            yield chunk
                            # break

                        except Exception as e:
                            _ = f"{e}\n{chunk}"
                            logger.error(_)
                            send_message(_)
                            yield ""
                    else:
                        yield ""


# 使用断点续传：
# 实现一个机制来记录已接收的数据量，在连接中断时从断点处继续：
# async def resumable_stream(client, url, payload, start_byte=0):
#     headers = {"Range": f"bytes={start_byte}-"}
#     while True:
#         try:
#             async with client.stream("POST", url, json=payload, headers=headers) as response:
#                 async for chunk in response.aiter_bytes():
#                     yield chunk
#                     start_byte += len(chunk)
#         except httpx.ReadTimeout:
#             print(f"Connection lost, resuming from byte {start_byte}")
#             continue
#         break

@alru_cache()
@retrying(title=__name__)
async def check_token(token):  ##########################
    headers = {
        'Cookie': token,
        'next-action': '9447c867550adf321952367efe04d997e4c7d9a5',
        # 'next-action': 'ca5ce500ddee37bddc3c986bee81b599f41e3efb'
    }
    # 0:["$@1",["EpTP5QUHhypCPwmq05kN6",null]]
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post("", json=CHECK_PAYLOAD)
        logger.debug(response.status_code)
        logger.debug(response.text)
        return response.is_success or "500" not in response.text  # 1:{"error":{"message":"User not found","status":500}}


if __name__ == '__main__':
    token = "HMACCOUNT_BFESS=2A2062EF2FE81046; io=4gPrU0FUQr5w60EmAdXS; Hm_lvt_a3c8711bce1795293b1793d35916c067=1726115406; Hm_lpvt_a3c8711bce1795293b1793d35916c067=1726115406; HMACCOUNT=2A2062EF2FE81046; _gcl_au=1.1.112315428.1726115409.331920663.1726115409.1726115409; id=221988a1d5f300f3||t=1726115409|et=730|cs=002213fd481785fd77a9cb7651; session=eyJhbGciOiJIUzI1NiJ9.eyJ1c2VyIjp7ImVtYWlsIjoiZjk5Y241ZGJhQG1haWwueGl1dmkuY24ifSwiZXhwaXJlcyI6IjIwMjQtMTItMjFUMDQ6MzA6MTcuMTQ5WiIsImlhdCI6MTcyNjExNTQxNywiZXhwIjoxNzM0NzU1NDE3fQ.G7MvMcx_96aHeVZV7I28Fssl14MqbhTyAkHIM8ZgwOk; __cf_bm=rAWQ3zYw5tpAvJSeP3uD8Sd0mZir3NbcJdqiLg3YHlE-1726115419-1.0.1.1-pPoQZFTpwqS1eGcSfxmSoGYOCHkxEVhPl8LVig05cFf.Ri3smhoG5KCzCcupGTtQOM0To5WwGbPLX24mP3rEpw"
    df = arun(aget_spreadsheet_values(feishu_url=FEISHU_URL_VIP, to_dataframe=True), debug=False)
    # df = arun(aget_spreadsheet_values(feishu_url=FEISHU_URL, to_dataframe=True), debug=False)

    api_keys = df[0]
    # api_keys = [token]
    for i, _ in enumerate(filter(None, api_keys)):
        # logger.debug(i)
        if token:
            # token = "__Host-next-auth.csrf-token=5aacaeb122d54d7ee0aea2b5f34b61425e259696c0677aeb5a337887d1ca1f78%7Cc5e3861a0501a66449f97b1a4b0128d4f740f334a69111c480ad037f129c1f60; __Secure-next-auth.callback-url=https%3A%2F%2Fwww.tryblend.ai%2F; _gcl_au=1.1.1117087196.1725410224.646576272.1726110797.1726110798; session=eyJhbGciOiJIUzI1NiJ9.eyJ1c2VyIjp7ImVtYWlsIjoiNzY4M0BuZXNjLmNuIn0sImV4cGlyZXMiOiIyMDI0LTEyLTIxVDAzOjEzOjQ4LjgyM1oiLCJpYXQiOjE3MjYxMTA4MjgsImV4cCI6MTczNDc1MDgyOH0.r3FIs9T_ai9geOEH8iVnLa8ouQQUs8_ifURHWu5XEUg"
            # arun(check_token(token))
            # break
            # token = None

            c = Completions(token, vip=True)
            request = ChatCompletionRequest(
                # model="claude-3-haiku-20240307",
                # model="claude-3-5-sonnet",
                model="perplexity-sonar-small",
                # model="gpt-4o-mini",

                # messages=[{'role': 'user', 'content': '南京天气怎么样'}],
                messages=[{'role': 'user', 'content': '你是谁'}],
                stream=False,

            )


            async def main():
                if request.stream:
                    async for i in await c.create(request):
                        print(i, end='')

                else:
                    for i in await c.create(request):
                        print(i, end='')


            arun(main())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : sora
# @Time         : 2024/12/20 16:10
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 动态测试
import json

from meutils.pipe import *
from meutils.db.redis_db import redis_aclient

from meutils.schemas.video_types import SoraVideoRequest, Video

from openai import AsyncOpenAI


class Tasks(object):

    def __init__(self, base_url: Optional[str] = None, api_key: str = None):
        self.api_key = api_key
        self.base_url = base_url
        self.client = AsyncOpenAI(api_key=self.api_key, base_url=self.base_url)

    async def create(self, request: SoraVideoRequest):  # todo 区分模型
        if video_object := await redis_aclient.get("sora"):
            video =  json.loads(video_object)
            logger.debug(bjson(video))
            return video

    async def get(self, task_id: str):
        if _ := await redis_aclient.get(task_id):
            try:
                video = json.loads(_)
                logger.debug(bjson(video))
                return video
            except Exception as e:
                pass

if __name__ == '__main__':
    arun(Tasks().get('74c084ec-2359-42ce-94c6-e19a0451fbf2'))
    # arun(Tasks().get('sora'))

    # arun(Tasks().create(SoraVideoRequest()))


# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .base import Type


class ZippedDocumentBase(Type):
    def match(self, buf):
        # start by checking for ZIP local file header signature
        idx = self.search_signature(buf, 0, 6000)
        if idx != 0:
            return

        return self.match_document(buf)

    def match_document(self, buf):
        raise NotImplementedError

    def compare_bytes(self, buf, subslice, start_offset):
        sl = len(subslice)

        if start_offset + sl > len(buf):
            return False

        return buf[start_offset:start_offset + sl] == subslice

    def search_signature(self, buf, start, rangeNum):
        signature = b"PK\x03\x04"
        length = len(buf)

        end = start + rangeNum
        end = length if end > length else end

        if start >= end:
            return -1

        try:
            return buf.index(signature, start, end)
        except ValueError:
            return -1


class OpenDocument(ZippedDocumentBase):
    def match_document(self, buf):
        # Check if first file in archive is the identifying file
        if not self.compare_bytes(buf, b"mimetype", 0x1E):
            return

        # Check content of mimetype file if it matches current mime
        return self.compare_bytes(buf, bytes(self.mime, "ASCII"), 0x26)


class OfficeOpenXml(ZippedDocumentBase):
    def match_document(self, buf):
        # Check if first file in archive is the identifying file
        ft = self.match_filename(buf, 0x1E)
        if ft:
            return ft

        # Otherwise check that the fist file is one of these
        if (
            not self.compare_bytes(buf, b"[Content_Types].xml", 0x1E)
            and not self.compare_bytes(buf, b"_rels/.rels", 0x1E)
            and not self.compare_bytes(buf, b"docProps", 0x1E)
        ):
            return

        # Loop through next 3 files and check if they match
        # NOTE: OpenOffice/Libreoffice orders ZIP entry differently, so check the 4th file
        # https://github.com/h2non/filetype/blob/d730d98ad5c990883148485b6fd5adbdd378364a/matchers/document.go#L134
        idx = 0
        for i in range(4):
            # Search for next file header
            idx = self.search_signature(buf, idx + 4, 6000)
            if idx == -1:
                return

            # Filename is at file header + 30
            ft = self.match_filename(buf, idx + 30)
            if ft:
                return ft

    def match_filename(self, buf, offset):
        if self.compare_bytes(buf, b"word/", offset):
            return (
                self.mime
                == "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
            )
        if self.compare_bytes(buf, b"ppt/", offset):
            return (
                self.mime
                == "application/vnd.openxmlformats-officedocument.presentationml.presentation"
            )
        if self.compare_bytes(buf, b"xl/", offset):
            return (
                self.mime
                == "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
            )


class Doc(Type):
    """
    Implements the Microsoft Word (Office 97-2003) document type matcher.
    """

    MIME = "application/msword"
    EXTENSION = "doc"

    def __init__(self):
        super(Doc, self).__init__(mime=Doc.MIME, extension=Doc.EXTENSION)

    def match(self, buf):
        if len(buf) > 515 and buf[0:8] == b"\xD0\xCF\x11\xE0\xA1\xB1\x1A\xE1":
            if buf[512:516] == b"\xEC\xA5\xC1\x00":
                return True
            if (
                len(buf) > 2142
                and b"\x00\x0A\x00\x00\x00MSWordDoc\x00\x10\x00\x00\x00Word.Document.8\x00\xF49\xB2q"
                in buf[2075:2142]
            ):
                return True

        return False


class Docx(OfficeOpenXml):
    """
    Implements the Microsoft Word OOXML (Office 2007+) document type matcher.
    """

    MIME = "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
    EXTENSION = "docx"

    def __init__(self):
        super(Docx, self).__init__(mime=Docx.MIME, extension=Docx.EXTENSION)


class Odt(OpenDocument):
    """
    Implements the OpenDocument Text document type matcher.
    """

    MIME = "application/vnd.oasis.opendocument.text"
    EXTENSION = "odt"

    def __init__(self):
        super(Odt, self).__init__(mime=Odt.MIME, extension=Odt.EXTENSION)


class Xls(Type):
    """
    Implements the Microsoft Excel (Office 97-2003) document type matcher.
    """

    MIME = "application/vnd.ms-excel"
    EXTENSION = "xls"

    def __init__(self):
        super(Xls, self).__init__(mime=Xls.MIME, extension=Xls.EXTENSION)

    def match(self, buf):
        if len(buf) > 520 and buf[0:8] == b"\xD0\xCF\x11\xE0\xA1\xB1\x1A\xE1":
            if buf[512:516] == b"\xFD\xFF\xFF\xFF" and (
                buf[518] == 0x00 or buf[518] == 0x02
            ):
                return True
            if buf[512:520] == b"\x09\x08\x10\x00\x00\x06\x05\x00":
                return True
            if (
                len(buf) > 2095
                and b"\xE2\x00\x00\x00\x5C\x00\x70\x00\x04\x00\x00Calc"
                in buf[1568:2095]
            ):
                return True

        return False


class Xlsx(OfficeOpenXml):
    """
    Implements the Microsoft Excel OOXML (Office 2007+) document type matcher.
    """

    MIME = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
    EXTENSION = "xlsx"

    def __init__(self):
        super(Xlsx, self).__init__(mime=Xlsx.MIME, extension=Xlsx.EXTENSION)


class Ods(OpenDocument):
    """
    Implements the OpenDocument Spreadsheet document type matcher.
    """

    MIME = "application/vnd.oasis.opendocument.spreadsheet"
    EXTENSION = "ods"

    def __init__(self):
        super(Ods, self).__init__(mime=Ods.MIME, extension=Ods.EXTENSION)


class Ppt(Type):
    """
    Implements the Microsoft PowerPoint (Office 97-2003) document type matcher.
    """

    MIME = "application/vnd.ms-powerpoint"
    EXTENSION = "ppt"

    def __init__(self):
        super(Ppt, self).__init__(mime=Ppt.MIME, extension=Ppt.EXTENSION)

    def match(self, buf):
        if len(buf) > 524 and buf[0:8] == b"\xD0\xCF\x11\xE0\xA1\xB1\x1A\xE1":
            if buf[512:516] == b"\xA0\x46\x1D\xF0":
                return True
            if buf[512:516] == b"\x00\x6E\x1E\xF0":
                return True
            if buf[512:516] == b"\x0F\x00\xE8\x03":
                return True
            if buf[512:516] == b"\xFD\xFF\xFF\xFF" and buf[522:524] == b"\x00\x00":
                return True
            if (
                len(buf) > 2096
                and buf[2072:2096]
                == b"\x00\xB9\x29\xE8\x11\x00\x00\x00MS PowerPoint 97"
            ):
                return True

        return False


class Pptx(OfficeOpenXml):
    """
    Implements the Microsoft PowerPoint OOXML (Office 2007+) document type matcher.
    """

    MIME = "application/vnd.openxmlformats-officedocument.presentationml.presentation"
    EXTENSION = "pptx"

    def __init__(self):
        super(Pptx, self).__init__(mime=Pptx.MIME, extension=Pptx.EXTENSION)


class Odp(OpenDocument):
    """
    Implements the OpenDocument Presentation document type matcher.
    """

    MIME = "application/vnd.oasis.opendocument.presentation"
    EXTENSION = "odp"

    def __init__(self):
        super(Odp, self).__init__(mime=Odp.MIME, extension=Odp.EXTENSION)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : ppio
# @Time         : 2025/8/22 11:05
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

models = {

    "glm-4.5": "zai-org/glm-4.5",

    "qwen3-235b-a22b-thinking-2507": "qwen/qwen3-235b-a22b-thinking-2507",
    "qwen3-235b-a22b-instruct-2507": "qwen/qwen3-235b-a22b-instruct-2507",
    "kimi-k2-0711-preview": "moonshotai/kimi-k2-instruct",
    "deepseek-v3.1": "deepseek/deepseek-v3.1",
    "deepseek-v3": "deepseek/deepseek-v3-turbo",
    "deepseek-v3-0324": "deepseek/deepseek-v3-0324",
    "deepseek-v3-250324": "deepseek/deepseek-v3-0324",

    # "deepseek/deepseek-v3/community"
    "deepseek-r1": "deepseek/deepseek-r1-turbo",
    "deepseek-reasoner": "deepseek/deepseek-r1-turbo",

    "deepseek-r1-250528": "deepseek/deepseek-r1-0528",

}

print(','.join(models))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : tripo3d_types
# @Time         : 2024/10/28 15:19
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

BASE_URL = "https://api.tripo3d.ai"
FEISHU_URL = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=KU4zY6"


class ImageRequest(BaseModel):
    model_version: Optional[str] = "v2.0-20240919"

    prompt: str

    render_sequence: Optional[bool] = True
    client_id: Optional[str] = "web"

    isPrivate: bool = False
    type: str = "text_to_model"
    name: str = ""

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.name = self.name or self.prompt


class TaskResponse(BaseModel):
    """
    {
        "code": 0,
        "data": {
            "task_ids": [
                "e327f716-6300-44ac-baf1-bdd57dd774a9",
                "3320b387-e049-4645-bce3-64636b454a3e",
                "c95fb37a-b766-4e3e-8b97-badf145d7a51",
                "41df5dd5-19c2-4df4-9f4f-71d0cf63d83e"
            ]
        }
    }
    """
    code: Optional[int] = None
    data: Optional[dict] = None
    task_ids: Optional[list] = None
    system_fingerprint: Optional[str] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)

        if self.data:
            self.task_ids = self.data.get('task_ids', [])



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : search_prompt
# @Time         : 2025/2/19 10:37
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 提示词模板

from meutils.pipe import *

current_date = datetime.datetime.now().strftime("%Y-%m-%d")

system_prompt = f"""你是一个具备网络访问能力的智能助手，在适当情况下，优先使用网络信息（参考信息）来回答，
以确保用户得到最新、准确的帮助。当前日期是 {current_date}。"""

# deepseek_prompt



 #!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
__title__ = 'cprint'
__author__ = 'JieYuan'
__mtime__ = '19-1-10'
"""


class Cprint(object):
    def __init__(self):
        colors = ['green', 'yellow', 'black', 'cyan', 'blue', 'red', 'white', 'purple']
        self.fc = dict(zip(colors, range(40, 97)))
        self.bc = dict(zip(colors, range(90, 97)))

    def cstring(self, s='Hello World !', bg='blue', fg='', mode=1):
        """
        :param s: string
        :param fg/bg: foreground/background
            'black', 'red', 'green', 'yellow', 'blue', 'purple', 'cyan', 'white'
        :param mode:
            0（默认值）
            1（高亮）
            22（非粗体）
            4（下划线）
            24（非下划线）
            5（闪烁）
            25（非闪烁）
            7（反显）
            27（非反显）
            https://www.cnblogs.com/hellojesson/p/5961570.html
        :return:
        """

        if fg:
            string = '\033[%s;%s;%sm%s\033[0m' % (mode, self.fc[fg], self.bc[bg], s)
        else:
            string = '\033[%s;%sm%s\033[0m' % (mode, self.bc[bg], s)
        return string

    def cprint(self, s='Hello World !', bg='blue', fg='', mode=1):
        print(self.cstring(s, bg, fg, mode))


c = Cprint()
cprint = c.cprint
cstring = c.cstring
if __name__ == '__main__':
    Cprint().cprint()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : es
# @Time         : 2023/3/14 上午10:38
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from whoosh import scoring
from whoosh.fields import *
from whoosh.filedb.filestore import FileStorage

from jieba.analyse import ChineseAnalyzer

# ME
from meutils.pipe import *


class EasySearch(object):

    def __init__(self, indexdir='whoosh_index', indexname='MAIN'):
        Path(indexdir).mkdir(parents=True, exist_ok=True)

        self.storage = FileStorage(indexdir)
        self.indexname = indexname

        self.ix = None
        if self.storage.index_exists(indexname=indexname):
            self.ix = self.storage.open_index(indexname)

    def create_index(self, df: pd.DataFrame, schema: Optional[Schema] = None, procs=4, limitmb=1024 * 2):
        schema = schema or Schema(
            id=ID(stored=True),
            text=TEXT(stored=True, analyzer=ChineseAnalyzer(cachesize=-1))  # 无界缓存加速
        )
        self.ix = self.storage.create_index(schema, indexname=self.indexname)
        writer = self.ix.writer(procs=procs, multisegment=True, limitmb=limitmb)
        for fields in tqdm(df.to_dict(orient='records'), 'Create Index'): # df: id text
            writer.add_document(**fields)
        writer.commit()

    def find(self, querystring, defaultfield: str = 'text', limit=5, weighting=scoring.BM25F, **kwargs):
        """

        @param defaultfield:
        @param querystring:
        @param limit:
        @param weighting: scoring.BM25F or scoring.TF_IDF()
        @param kwargs:
        @return:
        """
        assert self.ix is not None, 'please specify index !!!'

        with self.ix.searcher(weighting=weighting) as searcher:
            hits = searcher.find(defaultfield, querystring, limit=limit, **kwargs)
            df = pd.DataFrame([{**hit.fields(), 'score': hit.score} for hit in hits])
            df['runtime'] = hits.runtime

            return df


if __name__ == '__main__':
    from whoosh.fields import *

    df = pd.DataFrame([{'id': '1', 'text': '周杰伦'}] * 10)
    schema = Schema(
        id=ID(stored=True),
        text=TEXT(stored=True, analyzer=ChineseAnalyzer(cachesize=-1))  # 无界缓存加速
    )

    es = EasySearch('index')
    es.create_index(df, schema)
    print(es.find('周杰伦', 'text'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : remini
# @Time         : 2024/7/24 17:36
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import httpx

from meutils.pipe import *

# 上传文件
"https://app.remini.ai/result?utm_medium=try-remini&v=e0b2645d-59ee-496f-822b-61266422397a-1721800092479&mediaType=image"
"https://app.remini.ai/result?utm_medium=try-remini&v=e0b2645d-59ee-496f-822b-61266422397a-1721800092479&mediaType=image&taskId=75cb6bca-0dfb-444b-8f91-82daddde2976"


import requests
import json

url = "https://app.remini.ai/api/v1/web/tasks/bulk-upload"

payload = json.dumps({
   "input_task_list": [
      {
         "image_content_type": "image/jpeg",
         "output_content_type": "image/jpeg",
         "ai_pipeline": {
            "bokeh": {
               "vivid": "0.75",
               "highlights": "0.25",
               "group_picture": "true",
               "aperture_radius": "0.30",
               "apply_front_bokeh": "false",
               "rescale_kernel_for_small_images": "true"
            },
            "face_enhance": {
               "model": "remini"
            },
            "jpeg_quality": 90,
            "background_enhance": {
               "model": "rhino-tensorrt"
            }
         }
      }
   ]
})
headers = {
   'authorization': 'Bearer 54a2d77f30704a958a1b906ac1c74d44.a0e8b69805a9f1b10303b95109c3ffca735fe309400f5034f58cca54909c44f55c26f1506948e3050430788646b3a36406bc070243a3b436e6c14f3daa88ce54',
   'priority': 'u=1, i',
   'Cookie': 'OptanonAlertBoxClosed=2024-07-10T07:05:39.777Z; _hjSessionUser_3525893=eyJpZCI6Ijk2Yjk3Mzg1LThjY2UtNWFjZS05YzU1LWM2NmM1NmZjZGI0MyIsImNyZWF0ZWQiOjE3MjA1OTUxNTY3ODYsImV4aXN0aW5nIjp0cnVlfQ; _gid=GA1.2.926197006.1721800038; _hjSessionUser_3043925=eyJpZCI6IjZmMGRiYjgzLTgzYTUtNThiOS04NTNiLTk0OTc3NGVmMzRjNSIsImNyZWF0ZWQiOjE3MjA1OTUxMzMzNDQsImV4aXN0aW5nIjp0cnVlfQ; _pico_cid=1bcf4dbf-f2b4-4608-8a3b-6f58cc19212e; OptanonConsent=isGpcEnabled; _hjSessionUser_2996761=eyJpZCI6IjNmMWI4MThkLTNhZjMtNTE3YS1iM2ZmLTIwZTg4NDEzOTJmMSIsImNyZWF0ZWQiOjE3MjE4MDAwOTgyMDEsImV4aXN0aW5nIjpmYWxzZX0; __stripe_mid=b79bc88d-9f4a-45e2-a248-022e850ef050c24417; _ga_5LMYDNFSDH=GS1.1.1721813433.3.0.1721813433.0.0.0; _ga=GA1.1.471085307.1720595133; _hjSession_3043925=eyJpZCI6IjBmNWRlNGY5LTZiN2YtNDQxMC1iYzhlLWU1MjBlM2VhMjQzMyIsImMiOjE3MjE4MTM0MzMxODUsInMiOjAsInIiOjAsInNiIjowLCJzciI6MCwic2UiOjAsImZzIjowLCJzcCI6MH0; _hjSession_3525893=eyJpZCI6IjY3NzE0OWRkLTI0ZDAtNGU2Zi1iYjkwLTEyOTAxMzczYzQ3ZCIsImMiOjE3MjE4MTM0MzcxOTAsInMiOjEsInIiOjEsInNiIjowLCJzciI6MCwic2UiOjAsImZzIjowLCJzcCI6MH0',
   'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
   'content-type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
#
print(response.json())
#
# {
#     "bulk_upload_id": "939cb680-b80b-49f4-9098-28e36e9ac381",
#     "task_list": [
#         {
#             "task_id": "435c8a76-26eb-48bf-ba20-02df11648c97",
#             "upload_url": "https://storage.googleapis.com/bsp-remini-image-in-web-us-central1-autodelete/54a2d77f-3070-4a95-8a1b-906ac1c74d44/435c8a76-26eb-48bf-ba20-02df11648c97/25e310aa/input.jpg?X-Goog-Algorithm=GOOG4-HMAC-SHA256&X-Goog-Credential=GOOG1ETQDJI557KBP4YD5TQG6FMZHVKCP3S53FHI6XLBYYMT24W3PZAZNZZWQ%2F20240724%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20240724T093850Z&X-Goog-Expires=3600&X-Goog-SignedHeaders=content-type%3Bhost%3Bx-goog-custom-time&X-Goog-Signature=15a57b1f424d714d309533fec893c416ce8e7fb8841564ca7a7f5f16e9a2d2c3",
#             "upload_headers": {
#                 "Content-Type": "image/jpeg",
#                 "x-goog-custom-time": "2024-08-07T09:38:50Z"
#             }
#         }
#     ]
# }


file = open('test.png', 'rb').read()
files = [('file', ('x.png', file, 'image/png'))]
files ={'file': file}

upload_url = response.json()['task_list'][0]['upload_url']
upload_headers = response.json()['task_list'][0]["upload_headers"]
# r = httpx.options(upload_url, headers=headers)
# print(r.text)
headers = {**headers, **upload_headers}
print(headers)
r = httpx.put(upload_url, files=files, headers=headers)
print(r.text)

from meutils.io.files_utils import file_to_base64


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : deepseek_ocr
# @Time         : 2025/10/21 15:54
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.apis.hf.gradio import create_client, handle_file

from gradio_client import Client, handle_file

# client = create_client("khang119966/DeepSeek-OCR-DEMO")

with timer('xx'):
    client = Client("axiilay/DeepSeek-OCR-Demo")
# result = client.predict(
#     image=handle_file('https://s3.ffire.cc/files/pdf_to_markdown.jpg'),
#     model_size="Gundam (Recommended)",
#     task_type="📄 Convert to Markdown",
#     ref_text="Hello!!",
#     api_name="/process_ocr_task"
# )
# print(result)
# client = Client("khang119966/DeepSeek-OCR-DEMO")
# # client = Client("axiilay/DeepSeek-OCR-Demo")
# result = client.predict(
#     image=handle_file('https://s3.ffire.cc/files/pdf_to_markdown.jpg'),
#     model_size="Gundam (Recommended)",
#     task_type="📄 Convert to Markdown",
#     ref_text="Hello!!",
#     api_name="/process_ocr_task",
#
# )
# print(result)


# client.view_api(all_endpoints=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : cli_fastapi
# @Time         : 2023/8/4 15:01
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


from meutils.pipe import *


@cli.command()  # help会覆盖docstring
def celery_consumer(host='0.0.0.0', port: int = 8501):
    """
    # 消费者
    celery -A meutils.serving.celery.tasks worker -l info

    # 生产者
    mecli-server --host 127.0.0.1 --port 8000

    """

    from meutils.serving.fastapi import App
    from meutils.serving.celery.router import router

    app = App()
    app.include_router(router)
    app.run(host=host, port=port)


@cli.command()
def gunicorn_run(
        app: str,  # aiapi.views.apps:app
        project_dir: str = './',  # chdir
        port: int = 8501,
        workers: int = 3,
        threads: int = 2,
        preload: bool = False,
        pythonpath: str = 'python',
        gunicorn_conf: Optional[str] = None,
        max_requests: int = 1024 * 2,
        timeout: int = 120
):
    """
    python server.py gunicorn-run aiapi.views.apps:app --project-dir /Users/betterme/PycharmProjects/AI/aiapi

    todo:
        --chdir /Users/betterme/PycharmProjects/AI/aiapi 绝对路径
    """

    gunicorn_conf = gunicorn_conf or get_resolve_path('../serving/fastapi/gunicorn.conf.py', __file__)

    cmd = f"""
    cd {project_dir} && \
    {pythonpath} -m gunicorn -c {gunicorn_conf} \
      -k uvicorn.workers.UvicornWorker \
      --bind 0.0.0.0:{port} \
      --workers {workers} \
      --threads {threads} \
      --timeout {timeout} \
      --max-requests {max_requests} --max-requests-jitter 64 \
      {'--preload' if preload else ''} {app}
    """.strip()

    print(cmd)

    os.system(cmd)


@cli.command()
def uvicorn_run(
        app: str,
        project_dir: str = './',
        port: int = 8501,
        workers: int = 3,
        pythonpath: str = 'python',
        reload: bool = False,
):
    """
    python server.py uvicorn-run main:app --project-dir /Users/betterme/PycharmProjects/AI/aiapi
   -root-path
    """

    cmd = f"""
    cd {project_dir} && \
    {pythonpath} -m uvicorn {app} \
      --host 0.0.0.0 \
      --port {port} \
      --workers {workers}
    """.strip()
    if reload:
        cmd += ' --reload'

    print(cmd)

    os.system(cmd)


if __name__ == '__main__':
    cli()
